#CCP4I SCRIPT TEMPLATE crank

#
# crank.com
#
# This file generates the XML input file for Crank.  For data columns,
# it adds labels in the form INPUT_F_0 (where F is the column name and
# 0 is the number of the dataset in the .mtz file).  These labels
# won't be present in the MTZ file and must instead be prepared by
# crank_prepare.com, which takes the MTZ file input by the user and
# processes into a form suitable for Crank.
#

#
# General inputs and outputs, you can just cut and paste
# these when you add a new program to Crank.  The big one,
# "Experimental Columns" is first:
#
###############################################################################
# 1) Experimental Columns 
#    - Columns that come from the input .mtz from the user
#    - For the output side, just replace INPUT with OUTPUT
#
#1       	<exp_columns>
#LOOP K 1 $N_CRYSTALS
#1			<crystal id="$K">
#IF $CRYSTAL_NATIVE($K)
#1			   <data id="1">
#1				  <type>NATIVE</type>
#1				  <f>INPUT_F_X${K}_D1</f>
#1				  <sigf>INPUT_SIGF_X${K}_D1</sigf>
#1				  <i>INPUT_I_X${K}_D1</i>
#1				  <sigi>INPUT_SIGI_X${K}_D1</sigi>
#1			      <anomalous>0</anomalous>
#1			   </data>
#ELSE
#LOOP M 1 $N_DATA($K)
#1				<data id="$N">
#1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
#1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
#1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
#1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
#1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
#1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
#1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
#1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
#1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
#1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
#1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
#1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
#1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
#1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
#1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
#1				</data>
#ENDLOOP
#ENDIF
#1			</crystal>
#ENDLOOP
#1		  </exp_columns>
#
#############################################################################
# 2) F columns (F and sigF)
#
# 1            <f_columns>
# 1                 <f>$INPUT_F_COLUMNS($I)_F</f>
# 1                 <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
# 1            </f_columns>
#
#############################################################################
# 3) Phase columns (FB, PHIB and FOM)
#
# 1            <phase_columns>
# 1                 <fb>$INPUT_PHASE_COLUMNS($I)_FB</fb>
# 1                 <phib>$INPUT_PHASE_COLUMNS($I)_PHIB</phib>
# 1                 <fom>$INPUT_PHASE_COLUMNS($I)_FOM</fom>
# 1            </phase_columns>
#
#############################################################################
# 4) HL (Hendrickson-Lattman) columns (HLA, HLB, HLC, HLD)
#
# 1            <hl_columns>
# 1                 <hla>$INPUT_HL_COLUMNS($I)_HLA</hla>
# 1                 <hlb>$INPUT_HL_COLUMNS($I)_HLB</hlb>
# 1                 <hlc>$INPUT_HL_COLUMNS($I)_HLC</hlc>
# 1                 <hld>$INPUT_HL_COLUMNS($I)_HLD</hld>
# 1            </hl_columns>
#
#############################################################################
# 5) E-value columns (E, SIGE)
#
# 1            <evalue_columns>
# 1                 <e>$INPUT_EVALUE_COLUMNS($I)_E</e>
# 1                 <sige>$INPUT_EVALUE_COLUMNS($I)_SIGE</sige>
# 1            </evalue_columns>
#
#############################################################################
# 6) FA-value columns (FA, SIGFA)
#
# 1            <fa_columns>
# 1                 <fa>$INPUT_FA_COLUMNS($I)_FA</fa>
# 1                 <sigfa>$INPUT_FA_COLUMNS($I)_SIGFA</sigfa>
# 1            </fa_columns>
#
#############################################################################
# 6) Alpha columns (alpha) 
#      Alpha is the phase shift that should be added to the 
#      heavy atom phase to get the 'centroid' protein phase.
#
# 1            <alpha_columns>
# 1                 <alpha>$INPUT_ALPHA_COLUMNS($I)_ALPHA</alpha>
# 1            </alpha_columns>
#
#############################################################################
#
#
# 


1 <?xml version="1.0" standalone="yes"?>
1 <crank>
#
# Dataset descriptors from interface
#
1 <dataset_info>
1	<description>$TITLE</description>
1   <code>crank</code>
1 	<solvent_content>$SOLVENT_CONTENT</solvent_content>
1 	<residues>$NRESIDUES</residues>
IF { $NUCLEOTIDES_PRESENT }
1 	<nucleotides>$NNUCLEOTIDES</nucleotides>
ELSE
1   <nucleotides>0</nucleotides>
ENDIF
1   <atom_name>$ATOM_NAME</atom_name>
1   <natoms>$NATOMS</natoms>
1	<bfactor>$BFACTOR</bfactor>
# sness - We only need the total number of atoms
# for certain programs and can only get it either
# from the input Sequence or if the user enters all
# values by hand.
1   <all_atoms>
1       <c>$TOTAL_NUM_C</c>
1       <n>$TOTAL_NUM_N</n>
1       <o>$TOTAL_NUM_O</o>
1       <s>$TOTAL_NUM_S</s>
1       <p>$TOTAL_NUM_P</p>
1   </all_atoms>
1 </dataset_info>
1

#
# Description of the experimental data
#
1	<experimental_data>
LOOP K 1 $N_CRYSTALS
1		<crystal id="$K">
IF { $CRYSTAL_NATIVE($K) } 
1			<native>1</native>
1           <data id="1">
1				<type>NATIVE</type>
1				<anomalous>0</anomalous>
1           </data>
ELSE
1			<native>0</native>
1			<substructure>
IF { $CRYSTAL_INPUT_SUBSTRUCTURE($K) }
1			<coords>$CRYSTAL_SUBSTRUCTURE_INPUT_COORDSIN($K)</coords>
ELSE
1			<atom_name>$CRYSTAL_ATOM_NAME($K)</atom_name>
1			<natoms>$CRYSTAL_N_ATOMS($K)</natoms>
1			</substructure>
ENDIF
LOOP M 1 $N_DATA($K)
1			<data id="$M">
1				<type>$DATA_TYPE($K,$M)</type>
1				<anomalous>$DATA_ANOMALOUS($K,$M)</anomalous>
1				<wavelength>$DATA_WAVELENGTH($K,$M)</wavelength>
1				<fprime>$DATA_FPRIME($K,$M)</fprime>
1				<fprimeprime>$DATA_FPRIMEPRIME($K,$M)</fprimeprime>
1				<bfactor>$BFACTOR</bfactor>
1				<high_res_limit></high_res_limit>
1				<low_res_limit></low_res_limit>
1			</data>
ENDLOOP
ENDIF
1		</crystal>
ENDLOOP
1	</experimental_data>
1

#
# Input data files for Crank
#
1   <input_files>
# We only have one input MTZ file for now
1      <otherdata id="1">
1         <type>MTZ</type>
1         <label>MTZ1</label>
1 	      <filename>prep/output.mtz</filename>
1      </otherdata>
IF { $N_OTHERDATA > 0 }
LOOP K 1 $N_OTHERDATA
   LOOP L $K+1 $K+1
1		<otherdata id="$L">
1           <type>$OTHERDATA_TYPE($K)</type>
1           <label>$OTHERDATA_LABEL($K)</label>
IF { [StringSame $OTHERDATA_TYPE($K) SUBSTRUCTURE] }
1           <filename>$INPUT_COORDSIN($K)</filename>
ENDIF
IF { [StringSame $OTHERDATA_TYPE($K) PROTEIN_MODEL] }
1           <filename>$INPUT_XYZIN($K)</filename>
ENDIF
IF { [StringSame $OTHERDATA_TYPE($K) SEQUENCE] }
1           <filename>$SEQIN($K)</filename>
ENDIF
IF { [StringSame $OTHERDATA_TYPE($K) MAP] }
1           <filename>$MAPIN($K)</filename>
ENDIF
IF { [StringSame $OTHERDATA_TYPE($K) FREER] }
1           <freer>$FREER_LABEL($K)</freer>
ENDIF
1      </otherdata>
ENDLOOP
ENDLOOP
ENDIF
1   </input_files>
1

#
# Output data files for Crank
#
# sness - Ouch this is going to hurt, we will have to figure
# out what kinds of output are going to be necessary at the 
# end and map them here.  How do we even know what program
# should output these?  Should we perhaps do this for all
# programs that Crank runs?  This might be a good candidate
# for an "Output" module.
# Another approach would be to just output the last step. 
# This won't work as well if the last step is a visualization
# program or a verification program.
# It's a clue that this data structure doesn't look like the
# above that something is wrong.
#
# *** 
# My current solution is to avoid this completely by 
# just having MTZOUT, which is something we can control.
# I suspect the correct answer is to have an integrated
# browser in CCP4 to view the output from all steps.
# ***
1   <output_files>
1      <mtz_out>
1 	      <filename>$HKLOUT</filename>
1 	   </mtz_out>
# 1 	   <coords_out>
# 1 	      <filename>$COORDSOUT</filename>
# 1 	   </coords_out>
# 1 	   <pdb_out>
# 1 	      <filename>$XYZOUT</filename>
# 1 	   </pdb_out>
1   </output_files>
1

#
# The SOAP commands
#
1 <soap>
1 	<run>
1 		<directory>$rundir</directory>
1		<ccp4_job>sness23</ccp4_job>
1       <logfile>/home/sness/Crank/crank2-test3/run/sness23.logfile</logfile>
#
# Type of experiment
#
IF { [StringSame $CRANK_EXPERIMENT SIR] && $SIR_ANOMALOUS_DATA == 1 }
1       <experiment>SIRAS</experiment>
ELSE
1       <experiment>$CRANK_EXPERIMENT</experiment>
ENDIF

#
# The steps for Crank to run. 
#
# Loop over all experiments, outputting the appropriate section for
# each different program
#
LOOP I 1 $N_PROGRAMS

# Print the generic program run information 
# (This is useful in the case where we haven't added a specific
# program section below, in this case, we will just get a little <step>
# program header)
1
1	 <step id="$I">$PROGRAM_NAME($I)
1   	 <name>$PROGRAM_NAME($I)</name>
1		 <tag>$PROGRAM_TAG($I)</tag>

###################
# SCALEIT Section #
###################
IF { [StringSame $PROGRAM_NAME($I) SCALEIT] } 
#
# INPUT Section
#
1		<input>
#
# F columns
#
1           <f_columns>
1              <f>$INPUT_F_COLUMNS($I)_F</f>
1              <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1           </f_columns>
#
# Experimental Columns
#
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			   <data id="1">
1			      <f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				   <sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				   <i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				   <sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				   <anomalous>0</anomalous>
1			   </data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1         </input>
#
# OUTPUT Section
#
1         <output>


#
# Experimental Columns
#
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<f>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				<sigf>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				<i>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				<sigi>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$OUTPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1         <f_columns>
1              <f>$OUTPUT_PHASE_COLUMNS($I)_F</f>
1              <sigf>$OUTPUT_PHASE_COLUMNS($I)_SIGF</sigf>
1         </f_columns>
1         </output>
# Scaleit specific parameters
1           <scaleit>
# 1				<reference>
# 1					<crystal>$REFERENCE_CRYSTALNUM($I)</crystal>
# 1					<dataset>$REFERENCE_DATASETNUM($I)</dataset>
# 1				</reference>
1           </scaleit>
1
ENDIF

#		
# AFRO Section (Multivariate E-value calculation)
#
# sness - For now, we are just going to have a global set of
#         RESOLUTION, EXCLUDE and BINS for the interface, but
#         for the actual XML output, we want to describe it once
# 		  and for all, so we will describe it fully here.
IF { [StringSame $PROGRAM_NAME($I) AFRO] } 
# INPUT
1         <input>
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1         </input>
# OUTPUT
1         <output>
1         <evalue_columns>
1              <e>$OUTPUT_EVALUE_COLUMNS($I)_E</e>
1              <sige>$OUTPUT_EVALUE_COLUMNS($I)_SIGE</sige>
1         </evalue_columns>
1         <fa_columns>
1              <fa>$OUTPUT_FA_COLUMNS($I)_FA</fa>
1              <sigfa>$OUTPUT_FA_COLUMNS($I)_SIGFA</sigfa>
1         </fa_columns>
1         </output>
# Scaleit specific parameters
1           <afro>
1				<resolution_min>$AFRO_RESOLUTION_MIN($I)</resolution_min>
1				<resolution_max>$AFRO_RESOLUTION_MAX($I)</resolution_max>
1				<sigf>$AFRO_SIGF($I)</sigf>
1				<sano>$AFRO_SANO($I)</sano>
1				<bins>$AFRO_BINS($I)</bins>
1				<output>$AFRO_OUTPUT($I)</output>
1				<acentric>$AFRO_ACENTRIC($I)</acentric>
1				<centric>$AFRO_CENTRIC($I)</centric>
1				<title>$AFRO_TITLE($I)</title>
1				<interpolate>$AFRO_INTERPOLATE($I)</interpolate>
1				<verbose>$AFRO_VERBOSE($I)</verbose>
1           </afro>
ENDIF

#
# SHELXC Section (Direct methods for substructure determination)
#
IF { [StringSame $PROGRAM_NAME($I) SHELXC] } 
1         <input>
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1         </input>
1         <output>
1         <f_columns>
1              <f>$OUTPUT_F_COLUMNS($I)_F</f>
1              <sigf>$OUTPUT_F_COLUMNS($I)_SIGF</sigf>
1         </f_columns>
1         <fa_columns>
1              <fa>$OUTPUT_FA_COLUMNS($I)_FA</fa>
1              <sigfa>$OUTPUT_FA_COLUMNS($I)_SIGFA</sigfa>
1         </fa_columns>
1         <alpha_columns>
1              <alpha>$OUTPUT_ALPHA_COLUMNS($I)_ALPHA</alpha>
1         </alpha_columns>
1         </output>
# SHELXC specific parameters
1 	<shelx>
1 		<shel>
1 			<max>$SHELXC_LOW_RES_CUTOFF($I)</max>
1 			<min>$SHELXC_HIGH_RES_CUTOFF($I)</min>
1 		</shel>
1 	</shelx>
ENDIF

#
# DREAR Section (Direct methods for substructure solution)
#
IF { [StringSame $PROGRAM_NAME($I) DREAR] } 
1         <input>
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1         </input>
1         <output>
1            <f_columns>
1                 <f>$OUTPUT_F_COLUMNS($I)_F</f>
1                 <sigf>$OUTPUT_F_COLUMNS($I)_SIGF</sigf>
1            </f_columns>
1            <evalue_columns>
1                 <e>$OUTPUT_EVALUE_COLUMNS($I)_E</e>
1                 <sige>$OUTPUT_EVALUE_COLUMNS($I)_SIGE</sige>
1            </evalue_columns>
1         </output>
# Drear specific parameters
1           <drear>
1              <pmf>$DREAR_SEEDING($I)</pmf>
1              <scattering_power>15</scattering_power>
1              <max_resolution>$DREAR_HIGH_RES_CUTOFF($I)</max_resolution>
1              <min_atoms>3</min_atoms>
1              <ntrials>$DREAR_NUM_TRIALS($I)</ntrials>
1              <ncycles>$DREAR_NUM_CYCLES($I)</ncycles>
1              <drear>
1                 <xray_source>SYNCHROTRON($I)</xray_source>
1                 <tmax>$DREAR_DREAR_TMAX($I)</tmax>
1                 <xmin>$DREAR_DREAR_XMIN($I)</xmin>
1                 <ymin>$DREAR_DREAR_YMIN($I)</ymin>
1                 <zmin>$DREAR_DREAR_ZMIN($I)</zmin>
1                 <zmax>$DREAR_DREAR_ZMAX($I)</zmax>
1                 <local_scaling>$DREAR_DREAR_LOCAL_SCALING($I)</local_scaling>
1                 <scaling_cutoff>$DREAR_DREAR_CUTOFF($I)</scaling_cutoff>
1              </drear>
1           </drear>
ENDIF


#
# PMF Section (Direct methods for substructure solution)
#
IF { [StringSame $PROGRAM_NAME($I) PMF] } 
1         <input>
1            <evalue_columns>
1               <e>$INPUT_EVALUE_COLUMNS($I)_E</e>
1               <sige>$INPUT_EVALUE_COLUMNS($I)_SIGE</sige>
1            </evalue_columns>
1            <f_columns>
1               <f>$INPUT_F_COLUMNS($I)_F</f>
1               <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1            </f_columns>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1         </output>
# Pmf specific parameters
1           <pmf>
1              <npatt>1</npatt>
1              <max_resolution>4.0</max_resolution>
1			   <scattering_power>15</scattering_power>
1           </pmf>
ENDIF

#
# CRUNCH2 Section (Direct methods for substructure solution)
#
IF { [StringSame $PROGRAM_NAME($I) CRUNCH2] } 
1         <input>
1            <coords>$INPUT_SUBSTRUCTURES($I)</coords>
1            <evalue_columns>
1               <e>$INPUT_EVALUE_COLUMNS($I)_E</e>
1               <sige>$INPUT_EVALUE_COLUMNS($I)_SIGE</sige>
1            </evalue_columns>
1            <f_columns>
1               <f>$INPUT_F_COLUMNS($I)_F</f>
1               <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1            </f_columns>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1         </output>
# Crunch2 specific parameters
1           <crunch2>
1              <pmf>$CRUNCH2_SEEDING($I)</pmf>
1              <scattering_power>15</scattering_power>
1              <max_resolution>$CRUNCH2_HIGH_RES_CUTOFF($I)</max_resolution>
1              <min_atoms>3</min_atoms>
1              <ntrials>$CRUNCH2_NUM_TRIALS($I)</ntrials>
1              <ncycles>$CRUNCH2_NUM_CYCLES($I)</ncycles>
1              <drear>
1                 <xray_source>SYNCHROTRON($I)</xray_source>
1                 <tmax>$CRUNCH2_DREAR_TMAX($I)</tmax>
1                 <xmin>$CRUNCH2_DREAR_XMIN($I)</xmin>
1                 <ymin>$CRUNCH2_DREAR_YMIN($I)</ymin>
1                 <zmin>$CRUNCH2_DREAR_ZMIN($I)</zmin>
1                 <zmax>$CRUNCH2_DREAR_ZMAX($I)</zmax>
1                 <local_scaling>$CRUNCH2_DREAR_LOCAL_SCALING($I)</local_scaling>
1                 <scaling_cutoff>$CRUNCH2_DREAR_CUTOFF($I)</scaling_cutoff>
1              </drear>
1           <pmf>
1              <npatt>1</npatt>
1              <max_resolution>4.0</max_resolution>
1           </pmf>
1           </crunch2>
ENDIF


#
# SHELXD Section (Direct methods for substructure determination)
#
IF { [StringSame $PROGRAM_NAME($I) SHELXD] } 
1         <input>
1            <coords>$INPUT_SUBSTRUCTURES($I)</coords>
1			 <fa_columns>
1            	<fa>$INPUT_FA_COLUMNS($I)_FA</fa>
1            	<sigfa>$INPUT_FA_COLUMNS($I)_SIGFA</sigfa>
1       	 </fa_columns>
1			 <alpha_columns>
1            	<alpha>$INPUT_ALPHA_COLUMNS($I)_ALPHA</alpha>
1       	 </alpha_columns>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1         </output>
# SHELXD specific parameters
1 	<shelx>
1 		<dsul>$SHELX_DSUL($I)</dsul>
1 		<mind>$SHELX_MIND($I)</mind>
1 		<ntry>$SHELX_NUM_TRIALS($I)</ntry>
1 		<shel>
1 			<max>$SHELXD_LOW_RES_CUTOFF($I)</max>
1 			<min>$SHELXD_HIGH_RES_CUTOFF($I)</min>
1 		</shel>
1 		<pats>$SHELX_PATS($I)</pats>
1 		<weed>$SHELX_WEED($I)</weed>
1 	</shelx>
ENDIF

#
# USERCOORDS Section (Substructure coordinates from user input)
#
IF { [StringSame $PROGRAM_NAME($I) USERCOORDS] } 
1         <input>
1            <coords>$INPUT_SUBSTRUCTURES($I)</coords>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1         </output>
1 	<usercoords>
LOOP K 1 $USER_N_ATOMS
1 		<atom id="$K">
1			<atom_id>$USER_ATOM_ID($K)$K</atom_id>
1			<element>$USER_ATOM_ID($K)</element>
1			<x>$USER_ATOM_X($K)</x>
1			<y>$USER_ATOM_Y($K)</y>
1			<z>$USER_ATOM_Z($K)</z>
1			<occupancy>$USER_ATOM_OCCU($K)</occupancy>
1 		</atom>
ENDLOOP
1 	</usercoords>
ENDIF

#
# BP3 Section (Multivariate refinement and phasing)
#
IF { [StringSame $PROGRAM_NAME($I) BP3] } 
1         <input>
1            <coords>$INPUT_SUBSTRUCTURES($I)</coords>
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1            <columns_to_phase>all</columns_to_phase>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1            <phase_columns>
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_FOM</fom>
1              <phiboh>$OUTPUT_PHASE_COLUMNS($I)_PHIBOH</phiboh>
1            </phase_columns>
1            <hl_columns>
1              <hla>$OUTPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$OUTPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$OUTPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$OUTPUT_HL_COLUMNS($I)_HLD</hld>
1            </hl_columns>
1         </output>
1 	<bp3>
1 		<program>bp3</program>
1 		<mode>refine_normal</mode>
{ $BP3_BINS($I) }      <bins>$BP3_BINS($I)</bins>
{ $BP3_REFA($I) }      <refa>$BP3_REFA($I)</refa>
{ $BP3_CYCLES($I) }    <ncycles>$BP3_CYCLES($I)</ncycles>
{ $BP3_SHELDRICK($I) } <shel>$BP3_SHELDRICK($I)</shel>
1 	</bp3>
ENDIF

#
# MLPHARE Section (Multivariate refinement and phasing)
#
IF { [StringSame $PROGRAM_NAME($I) MLPHARE] } 
1         <input>
1            <coords>$INPUT_SUBSTRUCTURES($I)</coords>
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1            <columns_to_phase>all</columns_to_phase>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1            <phase_columns>
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_FOM</fom>
1              <phiboh>$OUTPUT_PHASE_COLUMNS($I)_PHIBOH</phiboh>
1            </phase_columns>
1            <hl_columns>
1              <hla>$OUTPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$OUTPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$OUTPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$OUTPUT_HL_COLUMNS($I)_HLD</hld>
1            </hl_columns>
1         </output>
1 	<mlphare>
1 		<program>mlphare</program>
1 		<mode>refine_normal</mode>
{ $MLPHARE_CYCLES($I) }    <ncycles>$MLPHARE_CYCLES($I)</ncycles>
1 	</mlphare>
ENDIF

#
# SOLOMON Section (Density modification)
#
IF { [StringSame $PROGRAM_NAME($I) SOLOMON] } 
1         <input>
1         <f_columns>
1              <f>$INPUT_F_COLUMNS($I)_F</f>
1              <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1         </f_columns>
1         <phase_columns>
1              <fb>$INPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$INPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$INPUT_PHASE_COLUMNS($I)_FOM</fom>
1         </phase_columns>
1         <hl_columns>
1              <hla>$INPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$INPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$INPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$INPUT_HL_COLUMNS($I)_HLD</hld>
1         </hl_columns>
1         </input>
1         <output>
1         <phase_columns>
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_FOM</fom>
1         </phase_columns>
1         <hl_columns>
1              <hla>$OUTPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$OUTPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$OUTPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$OUTPUT_HL_COLUMNS($I)_HLD</hld>
1         </hl_columns>
1         </output>
1 	<solomon>
1 		<program>solomon</program>
1		<start_res>$SOLMON_START_RES($I)</start_res>
1		<end_res>$SOLOMON_END_RES($I)</end_res>
1		<prep_cycles>$SOLOMON_PREP_CYCLES($I)</prep_cycles>
1		<ext_cycles>$SOLOMON_EXT_CYCLES($I)</ext_cycles>
1		<end_cycles>$SOLOMON_END_CYCLES($I)</end_cycles>
1		<flipping_factor>$SOLOMON_FLIPPING_FACTOR($I)</flipping_factor>
1		<radius>$SOLOMON_RADIUS($I)</radius>
1		<trunc_low>$SOLOMON_TRUNC_LOW($I)</trunc_low>
1		<trunc_high>$SOLOMON_TRUNC_HIGH($I)</trunc_high>
1	</solomon>
ENDIF

#
# DM Section (Density modification)
#
IF { [StringSame $PROGRAM_NAME($I) DM] } 
1         <input>
1         <f_columns>
1              <f>$INPUT_F_COLUMNS($I)_F</f>
1              <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1         </f_columns>
1         <phase_columns>
1              <fb>$INPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$INPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$INPUT_PHASE_COLUMNS($I)_FOM</fom>
1         </phase_columns>
1         <hl_columns>
1              <hla>$INPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$INPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$INPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$INPUT_HL_COLUMNS($I)_HLD</hld>
1         </hl_columns>
1         </input>
1         <output>
1         <phase_columns>
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_FOM</fom>
1         </phase_columns>
1         <hl_columns>
1              <hla>$OUTPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$OUTPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$OUTPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$OUTPUT_HL_COLUMNS($I)_HLD</hld>
1         </hl_columns>
1         </output>
1 	<dm>
1 		<program>dm</program>
1 		<mode>SOLV</mode>
1 		<combine>PERT</combine>
1 		<scheme>ALL</scheme>
1 		<ncycles>AUTO</ncycles>
1 		<ncsmask>1</ncsmask>
1   </dm>
ENDIF

#
# SHELXE Section (Direct methods for substructure determination)
#
IF { [StringSame $PROGRAM_NAME($I) SHELXE] } 
1         <input>
1           <coords>$INPUT_SUBSTRUCTURES($I)</coords>
1         	<f_columns>
1              <f>$INPUT_F_COLUMNS($I)_F</f>
1              <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1         	</f_columns>
1         	<fa_columns>
1              <fa>$INPUT_FA_COLUMNS($I)_FA</fa>
1              <sigfa>$INPUT_FA_COLUMNS($I)_SIGFA</sigfa>
1         	</fa_columns>
1         	<alpha_columns>
1              <alpha>$INPUT_ALPHA_COLUMNS($I)_ALPHA</alpha>
1         	</alpha_columns>
1         </input>
1         <output>
1           <f_columns>
1                <f>$OUTPUT_F_COLUMNS($I)_F</f>
1                <sigf>$OUTPUT_F_COLUMNS($I)_SIGF</sigf>
1           </f_columns>
1         	<phase_columns>
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_FOM</fom>
1         	</phase_columns>
1           <f_columns id="ha">
1                <f>$OUTPUT_F_COLUMNS($I)_HA_F</f>
1                <sigf>$OUTPUT_F_COLUMNS($I)_HA_SIGF</sigf>
1           </f_columns>
1         	<phase_columns id="ha">
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_HA_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_HA_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_HA_FOM</fom>
1         	</phase_columns>
1         </output>
# SHELXE specific parameters
1 	<shelx>
1 		<dsul>$SHELX_DSUL($I)</dsul>
1 		<mind>$SHELX_MIND($I)</mind>
1 		<ntry>$SHELX_NUM_TRIALS($I)</ntry>
1 		<shel>
1 			<max>$SHELXE_LOW_RES_CUTOFF($I)</max>
1 			<min>$SHELXE_HIGH_RES_CUTOFF($I)</min>
1 		</shel>
1 		<pats>$SHELX_PATS($I)</pats>
1 		<weed>$SHELX_WEED($I)</weed>
1 	</shelx>
ENDIF

#
# Resolve section (Density modification and Model building)
#
IF { [StringSame $PROGRAM_NAME($I) RESOLVE] } 
1         <input>
1			 <sequences>$INPUT_SEQUENCES($I)</sequences>
1            <f_columns>
1              <f>$INPUT_F_COLUMNS($I)_F</f>
1              <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1            </f_columns>
1            <phase_columns>
1              <fb>$INPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$INPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$INPUT_PHASE_COLUMNS($I)_FOM</fom>
1            </phase_columns>
1            <hl_columns>
1              <hla>$INPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$INPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$INPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$INPUT_HL_COLUMNS($I)_HLD</hld>
1            </hl_columns>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1            <protein_model>$PROGRAM_TAG($I)</protein_model>
1            <phase_columns>
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_FOM</fom>
1            </phase_columns>
1            <hl_columns>
1              <hla>$OUTPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$OUTPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$OUTPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$OUTPUT_HL_COLUMNS($I)_HLD</hld>
1            </hl_columns>
1         </output>
1 		  <resolve>
1            <mask_cycles>$RESOLVE_MASK_CYCLES($I)</mask_cycles>
1            <minor_cycles>$RESOLVE_MINOR_CYCLES($I)</minor_cycles>
1            <no_build>$RESOLVE_NO_BUILD($I)</no_build>
1            <build_mode>$RESOLVE_BUILD_MODE($I)</build_mode>
1            <prime_and_switch>$RESOLVE_PRIME_AND_SWITCH($I)</prime_and_switch>
1            <cut_up_model>$RESOLVE_CUT_UP_MODEL($I)</cut_up_model>
1            <cc_ratio>$RESOLVE_CC_RATIO($I)</cc_ratio>
1            <use_input_solvent>$RESOLVE_USE_INPUT_SOLVENT($I)</use_input_solvent>
1            <solvent_content>$RESOLVE_SOLVENT_CONTENT($I)</solvent_content>
1            <low_res_cutoff>$RESOLVE_LOW_RES_CUTOFF($I)</low_res_cutoff>
1            <high_res_cutoff>$RESOLVE_HIGH_RES_CUTOFF($I)</high_res_cutoff>
1         </resolve>
ENDIF

#
# ARP/wARP + REFMAC5 Section (Model building and refinement)
#
IF { [StringSame $PROGRAM_NAME($I) ARPWARP] } 
1         <input>
1            <coords>$INPUT_SUBSTRUCTURES($I)</coords>
1            <protein_model>$INPUT_PROTEIN_MODELS($I)</protein_model>
1       	<exp_columns>
LOOP K 1 $N_CRYSTALS
1			<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_F</f>
1				<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGF</sigf>
1				<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_I</i>
1				<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1				<data id="$M">
1					<f>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F</f>
1					<sigf>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF</sigf>
1					<f_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_PLUS</f_plus>
1					<sigf_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1					<f_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_F_MINUS</f_minus>
1					<sigf_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1					<dano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_DANO</dano>
1					<sigdano>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGDANO</sigdano>
1					<isym>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_ISYM</isym>
1					<i>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I</i>
1					<sigi>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI</sigi>
1					<i_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_PLUS</i_plus>
1					<sigi_plus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1					<i_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_I_MINUS</i_minus>
1					<sigi_minus>$INPUT_EXPERIMENTAL_COLUMNS($I)_X${K}_D${M}_SIGI_MINUS</sigi_minus>
1				</data>
ENDLOOP
ENDIF
1			</crystal>
ENDLOOP
1		  </exp_columns>
1            <f_columns>
1              <f>$INPUT_F_COLUMNS($I)_F</f>
1              <sigf>$INPUT_F_COLUMNS($I)_SIGF</sigf>
1            </f_columns>
1            <phase_columns>
1              <fb>$INPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$INPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$INPUT_PHASE_COLUMNS($I)_FOM</fom>
1            </phase_columns>
1            <hl_columns>
1              <hla>$INPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$INPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$INPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$INPUT_HL_COLUMNS($I)_HLD</hld>
1            </hl_columns>
1            <sadtarget_f1>$INPUT_EXPERIMENTAL_COLUMNS($I)>$INPUT_EXPERIMENTAL_COLUMNS($I)</sadtarget_f1>
1            <sadtarget_sigf1</sadtarget_sigf1>
1            <sadtarget_f2>$INPUT_EXPERIMENTAL_COLUMNS($I)>$INPUT_EXPERIMENTAL_COLUMNS($I)</sadtarget_f2>
1            <sadtarget_sigf2</sadtarget_sigf2>
1         </input>
1         <output>
1            <coords>$PROGRAM_TAG($I)</coords>
1            <protein_model>$PROGRAM_TAG($I)</protein_model>
1            <phase_columns>
1              <fb>$OUTPUT_PHASE_COLUMNS($I)_FB</fb>
1              <phib>$OUTPUT_PHASE_COLUMNS($I)_PHIB</phib>
1              <fom>$OUTPUT_PHASE_COLUMNS($I)_FOM</fom>
1            </phase_columns>
1            <hl_columns>
1              <hla>$OUTPUT_HL_COLUMNS($I)_HLA</hla>
1              <hlb>$OUTPUT_HL_COLUMNS($I)_HLB</hlb>
1              <hlc>$OUTPUT_HL_COLUMNS($I)_HLC</hlc>
1              <hld>$OUTPUT_HL_COLUMNS($I)_HLD</hld>
1            </hl_columns>
1         </output>
1 	<arpwarp>
1 		<program>arpwarp</program>
1		<nmol>$ARPWARP_NMOL($I)</nmol>
1		<big_cycles>$ARPWARP_BIG_CYCLES($I)</big_cycles>
1		<arp_cycles>$ARPWARP_ARP_CYCLES($I)</arp_cycles>
1		<ref_mode>$ARPWARP_REF_MODE($I)</ref_mode>
1		<freer>$ARPWARP_EXCLUDE_FREER($I)</freer>
1		<phase_restrain>$ARPWARP_PHASE_RESTRAIN($I)</phase_restrain>
1		<phase_blur>$ARPWARP_PHASE_BLUR($I)</phase_blur>
1		<scale>$ARPWARP_SCALE($I)</scale>
1		<scanis>$ARPWARP_SCANIS($I)</scanis>
1		<tlsonoff>$ARPWARP_TLSONOFF($I)</tlsonoff>
1		<refmac_ref_set>$ARPWARP_REFMAC_REF_SET($I)</refmac_ref_set>
1		<href_occu>$ARPWARP_HREF_OCCU($I)</href_occu>
1		<href_temp>$ARPWARP_HREF_TEMP($I)</href_temp>
1		<href_coor>$ARPWARP_HREF_COOR($I)</href_coor>
1		<use_sequence>$ARPWARP_SEQUENCE_IN($I)</use_sequence>
1		<sequence_file>$SEQIN($I)</sequence_file>
1		<side_after>$ARPWARP_SIDE_AFTER($I)</side_after>
1    </arpwarp>
ENDIF

1    </step>
1
ENDLOOP

1 	</run>
1 </soap>
1 </crank>
1


