#
# crank.tcl
#

#
# Tcl CCP4i interface for CRANK
#
# Copyright / GPL - Steven Ness 2004/2005
#

#
# crank - Automated macromolecular structure solution
#
# Copyright (C) 2004-2005 Steven Ness
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

package require BLT

#
# Experimental data input
# 
# Data is in the simplified form of
#   Crystal -> Substructure type and number (heavy atoms)
#      Dataset -> Columns of data, I/sigI (native) or I+/I- (anomalous)
#
proc crystal_proc { arrayname counter } {

	upvar #0 $arrayname array
	global configure

	OpenSubFrame frame -toggle_display CRYSTAL_NATIVE,$counter open 1

	CreateLine line \
		label "Native" \
		message "Crystal is a Native crystal : No heavy atoms, No Anomalous" \
		widget CRYSTAL_NATIVE \
		label "                                                       " \
		label "                                                       " \
		label "                                                       "

	CloseSubFrame

	OpenSubFrame frame -toggle_display CRYSTAL_NATIVE,$counter open 0
	
	OpenSubFrame frame -toggle_display CRYSTAL_INPUT_SUBSTRUCTURE,$counter open 0

	CreateLine line \
		label "Native" \
		message "Crystal is a Native crystal : No heavy atoms, No Anomalous" \
		widget CRYSTAL_NATIVE \
		label "Substructure Atom" \
		message "Element name of substructure atom" \
		widget CRYSTAL_ATOM_NAME -oblig \
		label "Number of Substructure Atoms" \
		message "Approximate number of substructure atoms to find" \
		widget CRYSTAL_N_ATOMS -oblig \
		label "    " \
		label "Input XML Substructure" \
		message "Input XML Substructure" \
		widget CRYSTAL_INPUT_SUBSTRUCTURE

	CloseSubFrame

	OpenSubFrame frame -toggle_display CRYSTAL_INPUT_SUBSTRUCTURE,$counter open 1

	CreateLine line \
		label "                                                                        " \
		label "                                                                        " \
		label "Input XML Substructure" \
		message "Input XML Substructure" \
		widget CRYSTAL_INPUT_SUBSTRUCTURE

 	CreateInputFileLine line \
         "Enter input substructure coordinate file name (COORDSIN)" \
 		"Substructure coordinates in" \
 		CRYSTAL_SUBSTRUCTURE_INPUT_COORDSIN \
 		CRYSTAL_SUBSTRUCTURE_DIR_INPUT_COORDSIN

	CloseSubFrame

	CloseSubFrame

	OpenSubFrame frame -toggle_display CRYSTAL_NATIVE,$counter open 1

 	CreateLabinLine line \
 		"I" \
 		HKLIN "I"  DATA_I  {} \
 		-sigma "SIGI" DATA_SIGI  {}

	CloseSubFrame

	OpenSubFrame frame -toggle_display CRYSTAL_NATIVE,$counter open 0

	CreateExtendingFrame N_DATA data_proc \
        "Define Data" \
        "Add new Dataset to this Crystal" \
		[list  DATA_TYPE \
			 DATA_CUKALPHA \
			 DATA_ANOMALOUS \
			 DATA_FPRIME \
			 DATA_FPRIMEPRIME \
			 DATA_WAVELENGTH \
			 DATA_TYPE \
			 DATA_I \
			 DATA_SIGI \
			 DATA_I_PLUS \
			 DATA_SIGI_PLUS \
			 DATA_I_MINUS \
			 DATA_SIGI_MINUS ] \
		-counter $counter 

	CloseSubFrame

	rebuild_varmenus $arrayname

}

#
# The Data part of Crystal.Data
#
proc data_proc { arrayname c2 counter } {

	upvar #0 $arrayname array
	global configure

	OpenSubFrame frame -toggle_display CRYSTAL_NATIVE,$counter open 0

	CreateLine line \
		label "Dataset : $c2" \
		message "Dataset : $c2" \
		label "Type" \
		message "Type" \
		widget DATA_TYPE \
		-command "rebuild_varmenus $arrayname" \
 		label "Anomalous" \
 		message "Anomalous" \
 		widget DATA_ANOMALOUS \
		label "                          " \
		label "Data collected at CuKalpha wavelength (1.54A)" \
		message "Estimate f' and f'' if the data was collected at the CuKalpha wavelength" \
		widget DATA_CUKALPHA

	CreateLine line \
		label "                                                     " \
		label "                                                     " \
		label "f'" \
		message "f' - F prime" \
		widget DATA_FPRIME -oblig \
		label "f''" \
		message "f'' - F double prime" \
		widget DATA_FPRIMEPRIME -oblig \
		label "Wavelength" \
		message "Wavelength" \
		widget DATA_WAVELENGTH \
		toggle_display [Indxv DATA_CUKALPHA $counter $c2] hide 1

	CloseSubFrame

 	CreateLabinLine line \
 		"I" \
 		HKLIN "I"  DATA_I  {} \
 		-sigma "SIGI" DATA_SIGI  {} \
		-toggle_display [Indxv DATA_ANOMALOUS $counter $c2] hide 1

	CreateLabinLine4 line \
		"IP" \
		HKLIN "IP+" DATA_I_PLUS {} \
		-sigma "SIGIP+" DATA_SIGI_PLUS {} \
		-dependent "IP-" DATA_I_MINUS {} \
		-sigma "SIGIP-" DATA_SIGI_MINUS {} \
		-toggle_display [Indxv DATA_ANOMALOUS $counter $c2] hide 0

	rebuild_varmenus $arrayname
}

proc add_othercolumn { arrayname counter } {
	upvar #0 $arrayname array

	rebuild_varmenus $arrayname
}

#
# Input other column types
#
# This is for when you want to take some data you have 
# generated in another program and use it with crank.
#
proc othercolumn_proc { arrayname counter } {
	upvar #0 $arrayname array
	global configure

	CreateLine line \
		label "Othercolumn : $counter" \
		message "Othercolumn : $counter" \
		label "     " \
		label "Type" \
		message "Type" \
		widget OTHERCOLUMN_TYPE \
		-command "add_othercolumn $arrayname $counter"

	# Input F columns (F and sigF) from MTZ file
 	CreateLabinLine line \
 		"F columns" \
 		HKLIN "F" OTHERCOLUMN_F {} \
 		-sigma "SIGF" OTHERCOLUMN_SIGF {} \
		-toggle_display [Indxv OTHERCOLUMN_TYPE $counter] open F_COLUMNS

 	# Input Phase columns (FB) from MTZ file
  	CreateLabinLine line \
  		"Phase columns" \
  		HKLIN "FB" OTHERCOLUMN_FB {} \
		-toggle_display [Indxv OTHERCOLUMN_TYPE $counter] open PHASE_COLUMNS

 	# Input Phase columns (PHIB and FOM) from MTZ file
  	CreateLabinLine line \
  		"Phase columns" \
  		HKLIN "PHIB" OTHERCOLUMN_PHIB {} \
  		-sigma "FOM" OTHERCOLUMN_FOM {} \
		-toggle_display [Indxv OTHERCOLUMN_TYPE $counter] open PHASE_COLUMNS

 	# Input HL (Hendrickson-Lattman) columns (HLA, HLB) from MTZ file
  	CreateLabinLine4 line \
  		"HL columns" \
  		HKLIN "HLA" OTHERCOLUMN_HLA OTHERCOLUMN_HLA \
		-dependent "HLB" OTHERCOLUMN_HLB OTHERCOLUMN_HLB \
		-dependent "HLC" OTHERCOLUMN_HLC OTHERCOLUMN_HLC \
		-dependent "HLD" OTHERCOLUMN_HLD OTHERCOLUMN_HLD \
		-toggle_display [Indxv OTHERCOLUMN_TYPE $counter] open HL_COLUMNS

 	# Input E-value columns (E, SIGE) from MTZ file
  	CreateLabinLine line \
  		"E-value columns" \
  		HKLIN "E" OTHERCOLUMN_E {} \
  		-sigma "SIGE" OTHERCOLUMN_SIGE {} \
		-toggle_display [Indxv OTHERCOLUMN_TYPE $counter] open EVALUE_COLUMNS

 	# Input FA-value columns (FA, SIGFA) from MTZ file
  	CreateLabinLine line \
  		"FA columns" \
  		HKLIN "FA" OTHERCOLUMN_FA {} \
  		-sigma "SIGFA" OTHERCOLUMN_SIGFA {} \
		-toggle_display [Indxv OTHERCOLUMN_TYPE $counter] open FA_COLUMNS

 	# Input Alpha columns (alpha) from MTZ file
  	CreateLabinLine line \
  		"Alpha columns" \
  		HKLIN "ALPHA" OTHERCOLUMN_ALPHA {} \
		-toggle_display [Indxv OTHERCOLUMN_TYPE $counter] open ALPHA_COLUMNS

}


proc add_otherdata { arrayname counter } {
	upvar #0 $arrayname array

	rebuild_varmenus $arrayname
}

#
# Input other column types
#
# This is for when you want to take some data you have 
# generated in another program and use it with crank.
#
proc otherdata_proc { arrayname counter } {
	upvar #0 $arrayname array
	global configure

	CreateLine line \
		label "Otherdata : $counter" \
		message "Otherdata : $counter" \
		label "     " \
		label "Type" \
		message "Type" \
		widget OTHERDATA_TYPE \
		-command "add_otherdata $arrayname $counter"

	# Substructure input
	CreateInputFileLine line \
        "Enter input substructure coordinate file name (COORDSIN)" \
		"Substructure coordinates in" \
		INPUT_COORDSIN DIR_INPUT_COORDSIN  \
		-fileout COORDSOUT DIR_COORDSOUT _crank_ \
		-toggle_display [Indxv OTHERDATA_TYPE $counter] open SUBSTRUCTURE

	# PDB model input
	CreateInputFileLine line \
        "Enter input coordinate file name (XYZIN)" \
		"PDB in" \
		INPUT_XYZIN DIR_INPUT_XYZIN \
		-fileout XYZOUT DIR_XYZOUT _crank_ \
		-toggle_display [Indxv OTHERDATA_TYPE $counter] open PROTEIN_MODEL

	# Sequence data input
 	CreateInputFileLine line \
 		"Enter name of file containing the sequence (SEQIN)" \
 		"Sequence in " \
 		SEQIN DIR_SEQIN \
		-toggle_display [Indxv OTHERDATA_TYPE $counter] open SEQUENCE

	# Map input
 	CreateInputFileLine line \
 		"Enter name of file containing the map (SEQIN)" \
 		"Map in " \
 		MAPIN DIR_MAPIN \
		-toggle_display [Indxv OTHERDATA_TYPE $counter] open MAP

	# Free-R flag input
	CreateLabinLine line \
		"Choose Free R column data (LABIN FREER)" \
		HKLIN FreeR FREER_LABEL [list FREE FreeR FreeR_flag] \
		-toggle_display [Indxv OTHERDATA_TYPE $counter] open FREER

}

proc rebuild_varmenus { arrayname } {
	global experimental_columns
	global f_columns
	global last_f_column	
	global phase_columns
	global hl_columns
	global evalue_columns
	global fa_columns
	global alpha_columns
	global substructures
	global protein_models
	global sequences
	global maps
	global freer

    global typedef
	upvar #0 $arrayname array

	# Each step has it's own set of varmenus, initialize all of these now
	for { set step 1 } { $step <= [expr $array(N_PROGRAMS) + 1] } { incr step } {
		set menulist_experimental_columns($step) {}
		set menulist_f_columns($step) {}
		set menulist_phase_columns($step) {}
		set menulist_hl_columns($step) {}
		set menulist_evalue_columns($step) {}
		set menulist_fa_columns($step) {}
		set menulist_alpha_columns($step) {}
		set menulist_substructures($step) {}
		set menulist_protein_models($step) {}
		set menulist_sequences($step) {}
		set menulist_maps($step) {}
		set menulist_freer($step) {}
	}

	# Loop over all program steps setting all the input sources
	# of data.  For this part, all the programs get identical 
	# lists.  It's only down below in the step part that the 
	# varmenus become different.
	for { set step 1 } { $step <= [expr $array(N_PROGRAMS) + 1] } { incr step } {

		#
		# Update the menulists for the CRYSTAL/DATASET section
		#
		# sness - Currently only one Input Experimental section
		lappend menulist_experimental_columns($step) "INPUT"
		for { set i 1 } { $i <= $array(N_CRYSTALS) } { incr i } {
			for { set j 1 } { $j <= $array(N_DATA,$i) } { incr j } {
				set type $array(DATA_TYPE,${i}_${j})
				set column "INPUT_X${i}_D${j}"
				lappend menulist_f_columns($step) $column
			}
		}

		#
		# Update the menulists for the OTHER COLUMNS section
		#
		for { set i 1 } { $i <= $array(N_OTHERCOLUMN) } { incr i } {
			set type $array(OTHERCOLUMN_TYPE,$i)
			#puts "othercol ($i) ($type)"
			if { [string compare $type "F columns"] == 0 } {
				lappend menulist_f_columns($step) "OTHER${i}_F"
			} elseif { [string compare $type "Phase columns"] == 0 } {
				lappend menulist_phase_columns($step) "OTHER${i}_PHASE"
			} elseif { [string compare $type "HL columns"] == 0 } {
				lappend menulist_hl_columns($step) "OTHER${i}_HL"
			} elseif { [string compare $type "E-value columns"] == 0 } {
				lappend menulist_evalue_columns($step) "OTHER${i}_EVALUE"
			} elseif { [string compare $type "FA columns"] == 0 } {
				lappend menulist_fa_columns($step) "OTHER${i}_FA"
			} elseif { [string compare $type "Alpha columns"] == 0 } {
				lappend menulist_alpha_columns($step) "OTHER${i}_ALPHA"
			}
		}

		#
		# Update the menulists for the OTHER DATA section
		#
		set num_substructures 0
		set num_protein_models 0
		set num_sequences 0
		set num_maps 0
		set num_freers 0
		for { set i 1 } { $i <= $array(N_OTHERDATA) } { incr i } {
			set type $array(OTHERDATA_TYPE,$i)
#			puts "othercol ($i) ($type)"
			if { [string compare $type "Substructure"] == 0 } {
#				puts "adding substructure SUBSTRUCTURE$num_substructures"
				incr num_substructures
				lappend menulist_substructures($step) "SUBSTRUCTURE$num_substructures"
			} elseif { [string compare $type "Protein Model"] == 0 } {
				incr num_protein_models
				lappend menulist_protein_models($step) "PROTEIN_MODEL$num_protein_models"
			} elseif { [string compare $type "Sequence"] == 0 } {
				incr num_sequences
				lappend menulist_sequences($step) "SEQUENCE$num_sequences"
			} elseif { [string compare $type "Map"] == 0 } {
				incr num_maps
				lappend menulist_maps($step) "MAP$num_maps"
			} elseif { [string compare $type "Freer flag"] == 0 } {
				incr num_freers
				lappend menulist_freer($step) "FREER$num_freers"
			}
		}
	}

	#
	# Update the menulists for the PROGRAM section
	#
#	puts "n_programs=($array(N_PROGRAMS)) last=($array(PROGRAM_NAME,$array(N_PROGRAMS)))"
	for { set menulist 1 } { $menulist <= [expr $array(N_PROGRAMS) + 1] } { incr menulist } {
		for { set step 1 } { $step < $menulist } { incr step } {
			set name $array(PROGRAM_NAME,$step)
			set tag $array(PROGRAM_TAG,$step)
#			puts "program name=($name) tag=($tag)"

			# In the section below, check what program is at this
			# step and set the various outputs based on what kind of
			# information this program outputs.
			if { [string compare $name "SCALEIT"] == 0 } {
#				puts "appending for SCALEIT ($tag)"
				lappend menulist_experimental_columns($menulist) $tag
				
				# Add an F_COLUMN for each CRYSTAL/DATASET pair
				for { set i 1 } { $i <= $array(N_CRYSTALS) } { incr i } {
					for { set j 1 } { $j <= $array(N_DATA,$i) } { incr j } {
						set type $array(DATA_TYPE,${i}_${j})
						set column "X${i}_D${j}"
						lappend menulist_f_columns($menulist) "${tag}_${column}"
					}
				}
			} elseif { [string compare $name "AFRO"] == 0 } {
				lappend menulist_evalue_columns($menulist) $tag
			} elseif { [string compare $name "PMF"] == 0 } {
				lappend menulist_substructures($menulist) $tag
			} elseif { [string compare $name "CRUNCH2"] == 0 } {
				lappend menulist_substructures($menulist) $tag
			} elseif { [string compare $name "BP3"] == 0 } {
				lappend menulist_phase_columns($menulist) $tag
				lappend menulist_hl_columns($menulist) $tag
				lappend menulist_substructures($menulist) $tag
			} elseif { [string compare $name "DM"] == 0 } {
				lappend menulist_phase_columns($menulist) $tag
				lappend menulist_hl_columns($menulist) $tag
			} elseif { [string compare $name "RESOLVE"] == 0 } {
				lappend menulist_phase_columns($menulist) $tag
				lappend menulist_hl_columns($menulist) $tag
				lappend menulist_protein_models($menulist) $tag
			} elseif { [string compare $name "SHELXC"] == 0 } {
				lappend menulist_f_columns($menulist) $tag
				lappend menulist_fa_columns($menulist) $tag
				lappend menulist_alpha_columns($menulist) $tag
			} elseif { [string compare $name "SHELXD"] == 0 } {
				lappend menulist_substructures($menulist) $tag
			} elseif { [string compare $name "SHELXE"] == 0 } {
				lappend menulist_phase_columns($menulist) $tag
			}
		}
	}

	#
	# Update all varmenus
	#
	for { set step 1 } { $step <= [expr $array(N_PROGRAMS) + 1] } { incr step } {

#		puts "menulist_experimental_columns($step)=$menulist_experimental_columns($step)"
		
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_EXPERIMENTAL_COLUMNS_LIST,$step $menulist_experimental_columns($step) \
			INPUT_EXPERIMENTAL_COLUMNS_ALIAS,$step $menulist_experimental_columns($step)

		# Update F columns
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_F_COLUMNS_LIST,$step $menulist_f_columns($step) \
			INPUT_F_COLUMNS_ALIAS,$step $menulist_f_columns($step)

		# Update Phase columns
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_PHASE_COLUMNS_LIST,$step $menulist_phase_columns($step) \
			INPUT_PHASE_COLUMNS_ALIAS,$step $menulist_phase_columns($step)

		# Update HL columns
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_HL_COLUMNS_LIST,$step $menulist_hl_columns($step) \
			INPUT_HL_COLUMNS_ALIAS,$step $menulist_hl_columns($step)

		# Update Evalue columns
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_EVALUE_COLUMNS_LIST,$step $menulist_evalue_columns($step) \
			INPUT_EVALUE_COLUMNS_ALIAS,$step $menulist_evalue_columns($step)

		# Update FA columns
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_FA_COLUMNS_LIST,$step $menulist_fa_columns($step) \
			INPUT_FA_COLUMNS_ALIAS,$step $menulist_fa_columns($step)

		# Update Alpha columns
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_ALPHA_COLUMNS_LIST,$step $menulist_alpha_columns($step) \
			INPUT_ALPHA_COLUMNS_ALIAS,$step $menulist_alpha_columns($step)

		# Update Substructures
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_SUBSTRUCTURES_LIST,$step $menulist_substructures($step) \
			INPUT_SUBSTRUCTURES_ALIAS,$step $menulist_substructures($step)

		# Update Protein Models
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_PROTEIN_MODELS_LIST,$step $menulist_protein_models($step) \
			INPUT_PROTEIN_MODELS_ALIAS,$step $menulist_protein_models($step)

		# Update Sequences
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_SEQUENCES_LIST,$step $menulist_sequences($step) \
			INPUT_SEQUENCES_ALIAS,$step $menulist_sequences($step)

		# Update Maps
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_MAPS_LIST,$step $menulist_maps($step) \
			INPUT_MAPS_ALIAS,$step $menulist_maps($step)

		# Update FreeR
		UpdateVariableMenu $arrayname initialise 0 \
			INPUT_FREER_LIST,$step $menulist_freer($step) \
			INPUT_FREER_ALIAS,$step $menulist_freer($step)
	}

	#
	# Set the correct default for all varmenus
	#
	# Currently, we just choose the last entry in the list, we will want
	# to do something smarter in the future.  This will also be part of the
	# graphical flowchart builder.
 	for { set step 1 } { $step <= [expr $array(N_PROGRAMS) + 1] } { incr step } {
# 		puts "menulist($menulist_experimental_columns($step))"
 		set array(INPUT_EXPERIMENTAL_COLUMNS,$step) [lindex $menulist_experimental_columns($step) [expr [llength $menulist_experimental_columns($step)] - 1]]
 		set array(INPUT_F_COLUMNS,$step) [lindex $menulist_f_columns($step) [expr [llength $menulist_f_columns($step)] -1]]
 		set array(INPUT_PHASE_COLUMNS,$step) [lindex $menulist_phase_columns($step) [expr [llength $menulist_phase_columns($step)] -1]]
 		set array(INPUT_HL_COLUMNS,$step) [lindex $menulist_hl_columns($step) [expr [llength $menulist_hl_columns($step)] -1]]
 		set array(INPUT_EVALUE_COLUMNS,$step) [lindex $menulist_evalue_columns($step) [expr [llength $menulist_evalue_columns($step)] -1]]
 		set array(INPUT_FA_COLUMNS,$step) [lindex $menulist_fa_columns($step) [expr [llength $menulist_fa_columns($step)] -1]]
 		set array(INPUT_ALPHA_COLUMNS,$step) [lindex $menulist_alpha_columns($step) [expr [llength $menulist_alpha_columns($step)] -1]]
 		set array(INPUT_SUBSTRUCTURES,$step) [lindex $menulist_substructures($step) [expr [llength $menulist_substructures($step)] -1]]
 		set array(INPUT_PROTEIN_MODELS,$step) [lindex $menulist_protein_models($step) [expr [llength $menulist_protein_models($step)] -1]]
 		set array(INPUT_SEQUENCES,$step) [lindex $menulist_sequences($step) [expr [llength $menulist_sequences($step)] -1]]
 		set array(INPUT_MAPS,$step) [lindex $menulist_maps($step) [expr [llength $menulist_maps($step)] -1]]
 		set array(INPUT_FREER,$step) [lindex $menulist_freer($step) [expr [llength $menulist_freer($step)] -1]]
 	}	

}

proc new_varmenu { arrayname counter } {

    global typedef
	
    if { ![info exists typedef(_input_experimental_columns_$counter)] } {
		set typedef(_input_experimental_columns_$counter) \
			[list varmenu INPUT_EXPERIMENTAL_COLUMNS_LIST,$counter INPUT_EXPERIMENTAL_COLUMNS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_EXPERIMENTAL_COLUMNS,$counter _input_experimental_columns_$counter ""
    }

    if { ![info exists typedef(_input_f_columns_$counter)] } {
		set typedef(_input_f_columns_$counter) \
			[list varmenu INPUT_F_COLUMNS_LIST,$counter INPUT_F_COLUMNS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_F_COLUMNS,$counter _input_f_columns_$counter ""
    }

    if { ![info exists typedef(_input_phase_columns_$counter)] } {
		set typedef(_input_phase_columns_$counter) \
			[list varmenu INPUT_PHASE_COLUMNS_LIST,$counter INPUT_PHASE_COLUMNS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_PHASE_COLUMNS,$counter _input_phase_columns_$counter ""
    }

    if { ![info exists typedef(_input_hl_columns_$counter)] } {
		set typedef(_input_hl_columns_$counter) \
			[list varmenu INPUT_HL_COLUMNS_LIST,$counter INPUT_HL_COLUMNS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_HL_COLUMNS,$counter _input_hl_columns_$counter ""
    }

    if { ![info exists typedef(_input_evalue_columns_$counter)] } {
		set typedef(_input_evalue_columns_$counter) \
			[list varmenu INPUT_EVALUE_COLUMNS_LIST,$counter INPUT_EVALUE_COLUMNS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_EVALUE_COLUMNS,$counter _input_evalue_columns_$counter ""
    }

    if { ![info exists typedef(_input_fa_columns_$counter)] } {
		set typedef(_input_fa_columns_$counter) \
			[list varmenu INPUT_FA_COLUMNS_LIST,$counter INPUT_FA_COLUMNS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_FA_COLUMNS,$counter _input_fa_columns_$counter ""
    }

    if { ![info exists typedef(_input_alpha_columns_$counter)] } {
		set typedef(_input_alpha_columns_$counter) \
			[list varmenu INPUT_ALPHA_COLUMNS_LIST,$counter INPUT_ALPHA_COLUMNS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_ALPHA_COLUMNS,$counter _input_alpha_columns_$counter ""
    }

    if { ![info exists typedef(_input_substructures_$counter)] } {
		set typedef(_input_substructures_$counter) \
			[list varmenu INPUT_SUBSTRUCTURES_LIST,$counter INPUT_SUBSTRUCTURES_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_SUBSTRUCTURES,$counter _input_substructures_$counter ""
    }

    if { ![info exists typedef(_input_protein_models_$counter)] } {
		set typedef(_input_protein_models_$counter) \
			[list varmenu INPUT_PROTEIN_MODELS_LIST,$counter INPUT_PROTEIN_MODELS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_PROTEIN_MODELS,$counter _input_protein_models_$counter ""
    }

    if { ![info exists typedef(_input_sequences_$counter)] } {
		set typedef(_input_sequences_$counter) \
			[list varmenu INPUT_SEQUENCES_LIST,$counter INPUT_SEQUENCES_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_SEQUENCES,$counter _input_sequences_$counter ""
    }

    if { ![info exists typedef(_input_maps_$counter)] } {
		set typedef(_input_maps_$counter) \
			[list varmenu INPUT_MAPS_LIST,$counter INPUT_MAPS_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_MAPS,$counter _input_maps_$counter ""
    }

    if { ![info exists typedef(_input_freer_$counter)] } {
		set typedef(_input_freer_$counter) \
			[list varmenu INPUT_FREER_LIST,$counter INPUT_FREER_ALIAS,$counter 20]
		DefineVariable $arrayname INPUT_FREER,$counter _input_freer_$counter ""
    }

}

#
# The main crank experiment design section
#
proc experiment_proc { arrayname counter } {
	upvar #0 $arrayname array

#	rebuild_varmenus $arrayname

	new_varmenu $arrayname $counter
	
	# Set the PROGRAM_NAME to the current program we are running
	set program $array(EXPERIMENTAL_PROGRAM)

	# Find if and where $program has the string "Program :" in it.
	set program_position [expr 10 + [string first "Program :" $program]]

	# If we are running a program, trim the "Program :" part off of it.
	if { $program_position == -1 } {
		# sness - Not a program, do we have to do something special?
		puts "*******************************************************************"
		puts "sness - This is not a program, do we have to do something special? "
		puts "*******************************************************************"
	} else {
		set program_string [string range $program $program_position [string length $program]]
	}

	# Set the correct PROGRAM_NAME to the string we just found
	set array(PROGRAM_NAME,$counter) $program_string
	set array(PROGRAM_TAG,$counter) "${counter}_${program_string}"
	
	#
	# Determine which program we should run and run it.   
	#
	# Also, setup the next program to be run:
	#  If we are running program X, then the next logical program is Y.
	#
	# In the future, this will also be dependant on the type of 
	# input data, data quality, data-base mining for regularities
	# heuristics, user-input rule bases.  But, that'll be more 
	# complicated.
	#

	# Scaling programs
	if { $array(EXPERIMENTAL_PROGRAM) == "Program : SCALEIT" } {
		scaleit_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : AFRO"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : FHSCAL" } {
		fhscal_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : CRUNCH2"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : SCALEIT_ANALYSE" } {
		scaleit_analyse_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : CRUNCH2"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : AFRO" } {
		afro_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : PMF"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : DREAR" } {
		drear_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : CRUNCH2"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : PREPHADATA" } {
		prephadata_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : CRUNCH2"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : SHELXC" } {
		shelxc_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : SHELXD"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : PMF" } {
		pmf_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : CRUNCH2"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : CRUNCH2" } {
		crunch2_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : BP3"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : RANTAN" } {
		rantan_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : BP3"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : SHELXD" } {
		shelxd_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : SHELXE"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : BP3" } {
		bp3_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : DM"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : MLPHARE" } {
		mlphare_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : SOLOMON"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : SOLOMON" } {
		solomon_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : DM"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : SHELXE" } {
		shelxe_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : DM"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : DM" } {
		dm_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : RESOLVE"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : PIRATE" } {
		pirate_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : RESOLVE"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : RESOLVE" } {
		resolve_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : RESOLVE"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : FFFEAR" } {
		fffear_proc $arrayname $counter
		set array(EXPERIMENTAL_PROGRAM) "Program : RESOLVE"
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : ARPWARP" } {
		arpwarp_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : REFMAC" } {
		refmac_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : REFMAC5D" } {
		refmac5D_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : SFCHECK" } {
		sfcheck_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : PROCHECK" } {
		procheck_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : Xfit" } {
		xfit_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : O" } {
		ono_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : Pymol" } {
		pymol_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : CCP4mg" } {
		ccp4mg_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Program : COOT" } {
		coot_proc $arrayname $counter
	} elseif { $array(EXPERIMENTAL_PROGRAM) == "Decision" } {
		decision_proc $arrayname $counter
	}

	# It would seem to make sense to rebuild the varmenus here, but
	# we actually want to rebuild them before we add new menu items.
	rebuild_varmenus $arrayname
}

proc decision_proc { arrayname counter } {
	upvar #0 $arrayname array

 	CreateLine line \
 		label "If " \
		widget PROGRAM_VARIABLES \
		widget PROGRAM_EQUALITIES \
		widget PROGRAM_VALUE \
		label " then " \
		widget PROGRAM_OUTCOMES \
		widget PROGRAM_OUTCOME_STEP

	puts "changing menu"


}

#
# Run SCALEIT on all derivatives automatically
# This is the one that will be used more by users
# but may take input from scaleittwo_proc
#
proc scaleit_proc { arrayname counter } {
	upvar #0 $arrayname array
	global experimental_columns
	global input_datasets

	#
	# As a default, set the input of this step to be the output of the last step (or steps)
	#
	# Set the experimental column to be the last experimental column determined
#	set last_experimental_column [lindex $experimental_columns [expr [llength $experimental_columns] -1]]
#	set current_experiment [expr [GetValue $arrayname N_PROGRAMS] + 1]
#	SetValue $arrayname INPUT_EXPERIMENTAL_COLUMNS,$current_experiment $last_experimental_column

 	CreateLine line \
 		label "SCALEIT will be used for scaling.  SCALEIT will scale *all* derivatives/wavelengths to the Reference                      "

	CreateLine line \
		label "Input Experimental Columns" \
		widget INPUT_EXPERIMENTAL_COLUMNS -width 23

	CreateLine line \
		label "Native F Column (reference column)" \
		widget INPUT_F_COLUMNS -width 23

	CreateLine line \
        message "Scale over limited resolution range (RESOLUTION)" \
		help resolution \
		widget SCALEIT_EXCLUDE_RESOLUTION -toggleon \
		label "Scale over resolution range " \
		widget SCALEIT_EXCLUDE_RESOLUTION_MIN \
		label "to" \
		widget SCALEIT_EXCLUDE_RESOLUTION_MAX

	CreateLine line \
		message "Refine the scale factors and isotropic/anomalous Bfactors (REFINE)" \
		help refine \
		label "Refine" \
		widget SCALEIT_REFINE_MODE \
		label "and    " \
		help refine_wilson \
		widget SCALEIT_WILSON_SCALING \
		label "apply Wilson scaling"

	CreateLine line \
		message "Weight observations for scale determination by their SDs (WEIGHT)" \
		help weight \
		widget SCALEIT_WEIGHT_BY_SD \
		label "Weight observations by their SDs" 

	CreateLine line \
		message "Converge after <n> cycles of refinement (CONVERGE NCYC)" \
		help converge_ncyc \
		widget SCALEIT_CONVERGE_NCYC \
		label "Converge after" \
		widget SCALEIT_CONVERGE_NCYC_LIMIT \
		label "cycles of refinement"

	CreateLine line \
        message \
		"Converge if all absolute shifts < SD of parameter (CONVERGE ABS)" \
		help converge_abs \
		widget SCALEIT_CONVERGE_ABS \
		label "Converge if absolute shift <" \
		widget SCALEIT_CONVERGE_ABS_LIMIT \
		label "SDs of parameter"

	CreateLine line \
        message \
		"Convergence tolerance (CONVERGE TOL)" \
		help converge_tolr \
		widget SCALEIT_CONVERGE_TOL \
		label "Convergence tolerance 10 to power" \
		widget SCALEIT_CONVERGE_TOL_LIMIT \

}




#
# Run AFRO to generate E-values
#
proc afro_proc { arrayname counter } {
	upvar #0 $arrayname array
	global experimental_columns

	#
	# As a default, set the input of this step to be the output of the last step (or steps)
	#
	# Set the experimental column to be the last experimental column determined
	set last_experimental_column [lindex $experimental_columns [expr [llength $experimental_columns] -1]]
	set current_experiment [expr [GetValue $arrayname N_PROGRAMS] + 1]
	SetValue $arrayname INPUT_EXPERIMENTAL_COLUMNS,$current_experiment $last_experimental_column

 	CreateLine line \
 		label "AFRO will be used to determine E-values.                                                                     " 

	CreateLine line \
		label "Input Experimental Columns" \
		widget INPUT_EXPERIMENTAL_COLUMNS -width 23

	CreateLine line \
		label "Low resolution cutoff" \
		widget AFRO_RESOLUTION_MIN \
		label "High resolution cutoff" \
		widget AFRO_RESOLUTION_MAX
	
	CreateLine line \
		label "Exclude reflections with FP < <nsigf> * SIGF" \
		widget AFRO_SIGF

	CreateLine line \
		label "exclude reflections in DANO < <nsano> * SANO" \
		widget AFRO_SANO

	CreateLine line \
		label "Number of bins for Luzatti parameter estimation" \
		widget AFRO_BINS
	
	CreateLine line \
		label "Interpolate neighbouring bin values to normalize" \
		widget AFRO_INTERPOLATE

}

#
# Run SHELXC to generate E-values
#
proc shelxc_proc { arrayname counter } {
	upvar #0 $arrayname array
	global experimental_columns

 	CreateLine line \
 		label "SHELXC will be used to determine E-values."

	CreateLine line \
		label "Input Experimental Columns" \
		widget INPUT_EXPERIMENTAL_COLUMNS -width 23

	CreateLine line \
		message "Low resolution cutoff" \
		label "Low resolution cutoff" \
		widget SHELXC_LOW_RES_CUTOFF

	CreateLine line \
		message "High resolution cutoff" \
		label "High resolution cutoff" \
		widget SHELXC_HIGH_RES_CUTOFF

}




proc pmf_proc { arrayname counter } {
	upvar #0 $arrayname array
# 	global f_columns
# 	global last_f_column
	global evalue_columns
	global substructures

 	# Set the evalue column to be the last evalue column determined
	set last_evalue_column [lindex $evalue_columns [expr [llength $evalue_columns] -1]]
	set current_experiment [expr [GetValue $arrayname N_PROGRAMS] + 1]
	SetValue $arrayname INPUT_EVALUE_COLUMNS,$current_experiment $last_evalue_column

	# Do the Substructure Column
	set last_substructure [lindex $substructures [expr [llength $substructures] -1]]
	set current_experiment [expr [GetValue $arrayname N_PROGRAMS] + 1]
	SetValue $arrayname INPUT_SUBSTRUCTURES,$current_experiment $last_substructure

 	CreateLine line \
 		label "PMF will be used for substructure determination"

	CreateLine line \
		label "Input F Columns" \
		widget INPUT_F_COLUMNS -width 23

	CreateLine line \
		label "Input E-value Columns" \
		widget INPUT_EVALUE_COLUMNS -width 23

	CreateLine line \
  		message "High resolution cutoff (0.5A below high res cutoff recommended)" \
  		label "High Res Cutoff:" \
  		widget PMF_HIGH_RES_CUTOFF \
  		button "Calculate" \
  		-command "runhighrescutoff $arrayname"

}


proc crunch2_proc { arrayname counter } {
	upvar #0 $arrayname array
	global evalue_columns
	global substructures
	global f_columns
	global last_f_column

 	CreateLine line \
 		label "CRUNCH2 will be used for substructure determination"

	CreateLine line \
		label "Input F Columns" \
		widget INPUT_F_COLUMNS -width 23

	CreateLine line \
		label "Input E-value Columns" \
		widget INPUT_EVALUE_COLUMNS -width 23

	CreateLine line \
		label "Input Substructures" \
		widget INPUT_SUBSTRUCTURES -width 23

	CreateLine line \
		message "Number of trials to perform (between 1-30 minutes per trial)" \
		label "Num. trials" \
		widget CRUNCH2_NUM_TRIALS \
		message "Number of cycles per trial" \
		label "Cycles per trial" \
		widget CRUNCH2_NUM_CYCLES \
		message "Perform seeding - Use Patterson Minimum Function (PMF) for seeding solutions" \
		label "Seeding" \
		widget CRUNCH2_SEEDING \
  		message "High resolution cutoff (0.5A below high res cutoff recommended)" \
  		label "High Res Cutoff:" \
  		widget CRUNCH2_HIGH_RES_CUTOFF \
  		button "Calculate" \
  		-command "runhighrescutoff $arrayname"

}


proc shelxd_proc { arrayname counter } {
	upvar #0 $arrayname array
	global fa_columns
	global alpha_columns
	global substructures

 	CreateLine line \
 		label "SHELXD will be used for substructure determination"

	CreateLine line \
		label "Input FA Columns" \
		widget INPUT_FA_COLUMNS -width 23

	CreateLine line \
		label "Input Alpha Columns" \
		widget INPUT_ALPHA_COLUMNS -width 23

 	CreateLine line \
 		message "Number of trials to perform (NTRY)" \
 		label "Num. trials" \
 		widget SHELXD_NUM_TRIALS \
 		message "Perform Patterson seeding (PATS)" \
 		label "Patterson seeding" \
 		widget SHELXD_PATS \
  		message "High resolution cutoff (0.5A below high res cutoff recommended)" \
  		label "High Res Cutoff:" \
  		widget SHELXD_HIGH_RES_CUTOFF \
  		button "Calculate" \
  		-command "runhighrescutoff $arrayname"
	
 	CreateLine line \
 		message "In this structure, is it possible to have heavy atoms on special positions?" \
 		label "Allow Special Positions?" \
 		widget SHELXD_SPECIAL_POSITIONS \
 		message "Turn off occupancy refinement?  (Reduces memory requirements)" \
 		label "Occupancy refinement?" \
 		widget SHELXD_OCCU_REFINE
	
	CreateLine line \
 		message "Minimum distance between atomic pairs - Reduce this to resolve sulphurs in disuphide bonds or atoms in clusters" \
 		label "Minimum distance between atoms" \
 		widget SHELXD_MIND \
 		message "Number of sulphurs participating in disulphide bonds in the structure." \
 		label "Number of Disulphide Sulphurs?" \
 		widget SHELXD_DSUL

}


proc bp3_proc { arrayname counter } {
	upvar #0 $arrayname array
	global experimental_columns
	global substructures

	#
	# The BP3 interface
	#
 	CreateLine line \
 		label "BP3 will be used for refinement and phasing"

	CreateLine line \
		label "Input Experimental Columns" \
		widget INPUT_EXPERIMENTAL_COLUMNS -width 23

	CreateLine line \
		label "Input Substructures" \
		widget INPUT_SUBSTRUCTURES -width 23

 	CreateLine line \
 		message "Sheldrick option - Do not refine atomic positions - Useful for when substructure is of very high quality" \
 		label "Do not refine atomic positions" \
 		widget BP3_SHELDRICK \
 		message "Number of cycles of refinement (leave blank for automatic termination)" \
 		label "Refinement cycles" \
 		widget BP3_CYCLES \
		message "Refine all parameters at once" \
 		label "Refine all parameters at once" \
 		widget BP3_REFA

}

proc mlphare_proc { arrayname counter } {
	upvar #0 $arrayname array
	global experimental_columns
	global substructures

	#
	# The MLPHARE interface
	#
 	CreateLine line \
 		label "MLPHARE will be used for refinement and phasing"

	CreateLine line \
		label "Input Experimental Columns" \
		widget INPUT_EXPERIMENTAL_COLUMNS -width 23

	CreateLine line \
		label "Input Substructures" \
		widget INPUT_SUBSTRUCTURES -width 23

 	CreateLine line \
 		message "Number of cycles of refinement (leave blank for automatic termination)" \
 		label "Refinement cycles" \
 		widget MLPHARE_CYCLES

}


proc dm_proc { arrayname counter } {
	upvar #0 $arrayname array
	global f_columns
	global last_f_column
	global phase_columns
	global hl_columns

 	CreateLine line \
 		label "DM will be used for density modification"

	CreateLine line \
		label "Input F Columns" \
		widget INPUT_F_COLUMNS -width 23

	CreateLine line \
		label "Input Phase Columns" \
		widget INPUT_PHASE_COLUMNS -width 23

	CreateLine line \
		label "Input HL Columns" \
		widget INPUT_HL_COLUMNS -width 23
	
    CreateLine line \
		message "Choose the mode(s) of density modification (MODE)" \
		help mode \
  		message "Use Solvent flattening, flatten solvent in unit cell" \
		widget DM_SOLVENT \
		label "Solvent flattening" \
  		message "Use histogram matching - Useful in almost all cases, except in unusual cases like with metal clusters" \
		widget DM_HISTOGRAM \
		label "Histogram matching" \
		message "Number of cycles of phase extension (NCYCLE) default is AUTO" \
  		help ncycle_auto \
		widget DM_NCYCLES_NOT_AUTO \
  		-toggleon \
		label "Fix number of cyles of phase extension to" \
  		help ncycle \
		widget DM_NCYCLES

}

proc shelxe_proc { arrayname counter } {
	upvar #0 $arrayname array
	global f_columns
	global last_f_column
	global fa_columns
	global alpha_columns
	global substructures

 	CreateLine line \
 		label "SHELXE will be used for density modification"

	CreateLine line \
		label "Input F Columns" \
		widget INPUT_F_COLUMNS -width 23

	CreateLine line \
		label "Input Fa Columns" \
		widget INPUT_FA_COLUMNS -width 23

	CreateLine line \
		label "Input ALPHA Columns" \
		widget INPUT_ALPHA_COLUMNS -width 23

	CreateLine line \
		label "Input Substructures" \
		widget INPUT_SUBSTRUCTURES -width 23

	CreateLine line \
		message "Resolve 2-fold ambiguity if SAD or SIR" \
		label "Resolve 2-fold ambiguity if SAD or SIR" \
		widget SHELXE_RESOLVE_2FOLD
	
	CreateLine line \
		message "Heavy atoms not present in native" \
		label "Heavy atoms not present in native" \
		widget SHELXE_NATIVE_HEAVY

	CreateLine line \
		message "92 point sphere, not 272" \
		label "92 point sphere, not 272" \
		widget SHELXE_BIG_SPHERE
	
	CreateLine line \
		message "Sharpen density maps" \
		label "Sharpen density maps" \
		widget SHELXE_SHARPEN_MAPS
	
	CreateLine line \
		message "High resolution limit for phasing" \
		label "High resolution limit for phasing" \
		widget SHELXE_HIGH_RES_CUTOFF
	
	CreateLine line \
		message "Cycles of density modification" \
		label "Cycles of density modification" \
		widget SHELXE_NCYCLES
	
	CreateLine line \
		message "Fraction of highest pixels used to resolve twofold ambiguity" \
		label "Fraction of highest pixels used to resolve twofold ambiguity" \
		widget SHELXE_2FOLD_FRACTION
	
	CreateLine line \
		message "Fraction of pixels in crossover region" \
		label "Fraction of pixels in crossover region" \
		widget SHELXE_CROSSOVER_FRACTION
	
	CreateLine line \
		message "Solvent gamma flipping factor" \
		label "Solvent gamma flipping factor" \
		widget SHELXE_GAMMA
	
	CreateLine line \
		message "Low density reduction factor" \
		label "Low density reduction factor" \
		widget SHELXE_LOWDENSITY_REDUCTION_FACTOR
	
	CreateLine line \
		message "Weight for retained experimental phases" \
		label "Weight for retained experimental phases" \
		widget SHELXE_EXPERIMENTAL_WEIGHT
	
	CreateLine line \
		message "Map resolution (multiplies maximum indices)" \
		label "Map resolution (multiplies maximum indices)" \
		widget SHELXE_RESOLUTION

}


proc resolve_proc { arrayname counter } {
	upvar #0 $arrayname array
	global experimental_columns
	global f_columns
	global last_f_column
	global phase_columns
	global hl_columns
	global substructures
	global sequences

  	CreateLine line \
  		label "RESOLVE will be used for density modification"

	CreateLine line \
		label "Input F Columns" \
		widget INPUT_F_COLUMNS -width 23

	CreateLine line \
		label "Input Phase Columns" \
		widget INPUT_PHASE_COLUMNS -width 23

	CreateLine line \
		label "Input HL Columns" \
		widget INPUT_HL_COLUMNS -width 23

	CreateLine line \
		label "Input Sequences" \
		widget INPUT_SEQUENCES -width 23

 	CreateLine line \
 		label "Mask Cycles" \
 		message "Number of cycles in which masks are redone and images are compared to map" \
 		widget RESOLVE_MASK_CYCLES \
 		label "Minor Cycles" \
 		message "Number of minor cycles per mask_cycle" \
 		widget RESOLVE_MINOR_CYCLES \
 		label "No build" \
 		message "Don't build a model" \
 		widget RESOLVE_NO_BUILD

	OpenSubFrame frame -toggle_display RESOLVE_USE_INPUT_SOLVENT,$counter open 1

 	CreateLine line \
 		label "Prime and Switch" \
 		message "Use prime-and-switch phasing. Use input phases only to calculate initial map. Input phase probabilities not used at all." \
 		widget RESOLVE_PRIME_AND_SWITCH \
		label "Solvent content" \
		message "Solvent content to use only for this Resolve step" \
		widget RESOLVE_SOLVENT_CONTENT \
 		label "Use user input solvent content" \
 		message "Do not search for optimal solvent content" \
 		widget RESOLVE_USE_INPUT_SOLVENT

	CloseSubFrame

	OpenSubFrame frame -toggle_display RESOLVE_USE_INPUT_SOLVENT,$counter open 0

 	CreateLine line \
 		label "Prime and Switch" \
 		message "Use prime-and-switch phasing. Use input phases only to calculate initial map. Input phase probabilities not used at all." \
 		widget RESOLVE_PRIME_AND_SWITCH \
 		label "Use user input solvent content" \
 		message "Do not search for optimal solvent content" \
 		widget RESOLVE_USE_INPUT_SOLVENT

	CloseSubFrame

 	CreateLine line \
 		label "High resolution limit" \
 		message "High resolultion limit" \
 		widget RESOLVE_HIGH_RES_CUTOFF \
 		label "Low resolution limit" \
 		message "Low resolultion limit" \
 		widget RESOLVE_LOW_RES_CUTOFF
}


proc ccp4mg_proc { arrayname counter } {
	upvar #0 $arrayname array
	global experimental_columns
	global f_columns
	global last_f_column
	global phase_columns
	global hl_columns
	global substructures
	global protein_models
	global maps

  	CreateLine line \
  		label "CCP4MG will be used for data display"

	CreateLine line \
		label "Input Experimental Columns" \
		widget INPUT_EXPERIMENTAL_COLUMNS -width 23

	CreateLine line \
		label "Input F Columns" \
		widget INPUT_F_COLUMNS -width 23

	CreateLine line \
		label "Input Phase Columns" \
		widget INPUT_PHASE_COLUMNS -width 23

	CreateLine line \
		label "Input HL Columns" \
		widget INPUT_HL_COLUMNS -width 23

	CreateLine line \
		label "Input Substructures" \
		widget INPUT_SUBSTRUCTURES -width 23

	CreateLine line \
		label "Input Protein_Models" \
		widget INPUT_PROTEIN_MODELS -width 23

	CreateLine line \
		label "Input Maps" \
		widget INPUT_MAPS -width 23
}

proc debug_output_all_vars { arrayname } {
	upvar #0 $arrayname array

  	set allvars [array get array]
  	for { set i 0 } { $i < [llength $allvars] } { incr i } {
  		puts -nonewline "[lindex $allvars $i]\t"
  		incr i
  		puts "[lindex $allvars $i] "
  	}
}

#
# Clear all current program steps
#
proc clear_pipeline { arrayname } {
	upvar #0 $arrayname array
	
	puts "Clearing all"

	SetSystemVar block_scroll_update 1
	set n_prog $array(N_PROGRAMS)
	puts "n_prog=$n_prog"
	for { set i 0 } { $i < $n_prog } { incr i} {
		delete_frame $arrayname experiment_proc 0
	}
	SetSystemVar block_scroll_update 0
	update_main_scroll $array(FRAME_experiment_proc_0)

}

#
# Clear all current program steps and make the default pipeline
#
proc default_pipeline { arrayname } {
	upvar #0 $arrayname array
	
	puts "Clearing all and making default pipeline"

	# First, clear all the program steps from the pipeline
	SetSystemVar block_scroll_update 1
	set n_prog $array(N_PROGRAMS)
	puts "n_prog=$n_prog"
	for { set i 0 } { $i < $n_prog } { incr i} {
		delete_frame $arrayname experiment_proc 0
	}
	SetSystemVar block_scroll_update 0
	update_main_scroll $array(FRAME_experiment_proc_0)

	set array(EXPERIMENTAL_PROGRAM) "Program : AFRO"
	update_toggleframe0 experiment_proc 0 $arrayname N_PROGRAMS 1 0
	update_toggleframe0 experiment_proc 0 $arrayname N_PROGRAMS 1 0
	update_toggleframe0 experiment_proc 0 $arrayname N_PROGRAMS 1 0
	update_toggleframe0 experiment_proc 0 $arrayname N_PROGRAMS 1 0
	update_toggleframe0 experiment_proc 0 $arrayname N_PROGRAMS 1 0
	update_toggleframe0 experiment_proc 0 $arrayname N_PROGRAMS 1 1

	rebuild_varmenus $arrayname

}

#
# Check to see if $atomname is present in the file
# $CLIBD/atomsf.lib
#
proc GoodAtomName { arrayname } {
	upvar #0 $arrayname array
	global env
	
	set atomname [string tolower $array(ATOM_NAME)]
	#puts "atomname=($atomname)"
	set atomsf "$env(CLIBD)/atomsf.lib"

	set file_id [open $atomsf r]

	set done 0
	while { !$done } {
		gets $file_id line
		if { ! [regexp {AD.*} $line]} {
			set done 1
		}
	}
	
	lappend atomlist $line
	gets $file_id line
	gets $file_id line
	gets $file_id line
	gets $file_id line

	while { [gets $file_id line] >= 0 } {
		lappend atomlist $line
		gets $file_id line
		gets $file_id line
		gets $file_id line
		gets $file_id line
		lappend cu_structure_factors $line
	}

	set match 0
	for { set i 0 } { $i < [llength $atomlist] } { incr i } {
		if { [regexp {([A-Za-z+0-9-]*) } [lindex $atomlist $i] full atom] } {
			set atom [string tolower $atom]
			if { [string compare $atomname $atom] == 0 } {
				set match 1
				set i [expr $i - 1]
				set fprime  [lindex [lindex $cu_structure_factors $i] 0]
				set fprimeprime [lindex [lindex $cu_structure_factors $i] 1]
				break
			}
		}
	}


	if { $match == 1 } {
		#puts "Match found ($atomname) ($atom)"
		return 1
	} else {
		#puts "Match not found for ($atomname)"
		return 0
	}

}

#
# Get the atomic form factors for $atomname from the information in
# $CLIBD/atomsf.lib
#
proc GetFormFactors { atomname } {
	global env
	
	set atomname [string tolower $atomname]
	set atomsf "$env(CLIBD)/atomsf.lib"

	set file_id [open $atomsf r]

	set done 0
	while { !$done } {
		gets $file_id line
		if { ! [regexp {AD.*} $line]} {
			set done 1
		}
	}
	
	lappend atomlist $line
	gets $file_id line
	gets $file_id line
	gets $file_id line
	gets $file_id line

	while { [gets $file_id line] >= 0 } {
		lappend atomlist $line
		gets $file_id line
		gets $file_id line
		gets $file_id line
		gets $file_id line
		lappend cu_structure_factors $line
	}

	set match 0
	for { set i 0 } { $i < [llength $atomlist] } { incr i } {
		if { [regexp {([A-Za-z+0-9-]*) } [lindex $atomlist $i] full atom] } {
			set atom [string tolower $atom]
			if { [string compare $atomname $atom] == 0 } {
				set match 1
				set i [expr $i - 1]
				set fprime  [lindex [lindex $cu_structure_factors $i] 0]
				set fprimeprime [lindex [lindex $cu_structure_factors $i] 1]
				break
			}
		}
	}

	if { $match == 1 } {
		return "$fprime $fprimeprime"
	} else {
		return "0.0 0.0"
	}

}


#
# Calculate optimal data cutoff
#
proc calculate_optimal_cutoff { arrayname } {
	upvar #0 $arrayname array

	puts "Calculating optimal cutoff"

	return 1

}


#
# From the number of residues, calculate the approximate
# number of carbon, nitrogen, oxygen, sulphur and phosphorus
# atoms present in the asymmetric unit
#
# In the future, to be integrated with reading a sequence file.
#
proc calculate_from_contents { arrayname } {
	upvar #0 $arrayname array

	set num_c_pro 0
	set num_n_pro 0
	set num_o_pro 0
	set num_s_pro 0
	set num_c_dna 0
	set num_n_dna 0
	set num_o_dna 0
	set num_p_dna 0

	if { $array(NRESIDUES) != "" } {
		set num_c_pro [expr int($array(NRESIDUES) * 4.869)]
		set num_n_pro [expr int($array(NRESIDUES) * 1.351)]
		set num_o_pro [expr int($array(NRESIDUES) * 1.492)]
		set num_s_pro [expr int($array(NRESIDUES) * 0.051)]
	}

	if { $array(NNUCLEOTIDES) != "" } {
		# SHARP Numbers - These don't work for the dna360 test case
		# 		set num_c_dna [expr int($array(NNUCLEOTIDES) * 9.683)]
		# 		set num_n_dna [expr int($array(NNUCLEOTIDES) * 3.911)]
		# 		set num_o_dna [expr int($array(NNUCLEOTIDES) * 6.424)]
		# 		set num_p_dna [expr int($array(NNUCLEOTIDES) * 1.000)]
		# Numbers directly from the DNA360 test case
 		set num_c_dna [expr int($array(NNUCLEOTIDES) * 10.583)]
 		set num_n_dna [expr int($array(NNUCLEOTIDES) * 4.333)]
 		set num_o_dna [expr int($array(NNUCLEOTIDES) * 12.333)]
 		set num_p_dna [expr int($array(NNUCLEOTIDES) * 1.000)]

	}

	
	set array(CRUNCH2_DREAR_NUM_C) [expr $num_c_pro + $num_c_dna]
	set array(CRUNCH2_DREAR_NUM_N) [expr $num_n_pro + $num_n_dna]
	set array(CRUNCH2_DREAR_NUM_O) [expr $num_o_pro + $num_o_dna]
	set array(CRUNCH2_DREAR_NUM_S) $num_s_pro
	set array(CRUNCH2_DREAR_NUM_P) $num_p_dna

	return

}

#
# Run SHELXC and from the output it produces, determine
# the optimal cutoff resolution.
#
proc runhighrescutoff { arrayname } {
	upvar #0 $arrayname array
	
	# Calculate optimal data cutoff
	# (Right now, only takes high res cutoff + 0.5A)
	# (but soon will run SHELXC to calculate the cutoff)

	if { $array(HIGH_RES_LIMIT) != 0.0 && $array(HIGH_RES_LIMIT) != "" } {
		set high_res_cutoff [expr $array(HIGH_RES_LIMIT) + 0.5]
		#puts "high resolution cutoff=$high_res_cutoff"
		set array(SHELX_HIGH_RES_CUTOFF) $high_res_cutoff
		set array(PMF_HIGH_RES_CUTOFF) $high_res_cutoff
		set array(CRUNCH2_HIGH_RES_CUTOFF) $high_res_cutoff
	}

	return
}

#
# runwilson
#
# A little procedure that will run the WILSON program to calculate
# the b-factor and solvent content of your data
#
# For now, we will do the calculation of b-factor and solvent based
# on the first dataset of the first crystal only.  Eventually it
# would be nice to do this for all crystals and datasets separately.
#
proc runwilson { arrayname } {
	upvar #0 $arrayname array

  	# Check that at least one dataset is present
  	if { $array(HKLIN) == "" } {
  		WarningMessage "You must first select a .mtz file"
  		return
  	}

	# The MTZ file to analyze
	set input_mtz [GetFullFileName0 $arrayname HKLIN]

	set fp $array(WILSON_F)
	set sigfp $array(WILSON_SIGF)

	#
	# Run a number of checks on the data, to make sure we really can 
	# run the WILSON program.  If the WILSON program has an error,
	# a huge unuseful window will pop up.
	#
	if { [string compare $fp "Unassigned"] == 0 || $fp == "" } {
		WarningMessage "FP column not set, please set it before calculating B-factor and Solvent Content"
		return 0
	}

	if { [string compare $sigfp "Unassigned"] == 0 || $sigfp == "" } {
		WarningMessage "SIGFP column not set, please set it before calculating B-factor and Solvent Content"
		return 0
	}

	# Set the number of residues mostly for solvent content, also has a small effect on b-factor
	# If the user hasn't or can't set NRESIDUES, use a default of 100 residues.
	if { $array(NRESIDUES) == "" } {
		WarningMessage "You must set both the number of residues and number of nucleotides\nto calculate b-factors and solvent content\nEither, but not both can be zero"
		return
	}

	if { $array(NRESIDUES) < 0 } {
		WarningMessage "Number of residues must be greater than 0"
		return
	}

	if { $array(NUCLEOTIDES_PRESENT) } {
		if { $array(NNUCLEOTIDES) == "" } {
			WarningMessage "You must set both the number of residues and number of nucleotides\nto calculate b-factors and solvent content\nEither, but not both can be zero"
			return
		}

		if { $array(NNUCLEOTIDES) < 0 } {
			WarningMessage "Number of nucleotides must be greater than 0"
			return
		}
	}

	if { $array(NUCLEOTIDES_PRESENT) } {
		set nresidues [expr $array(NRESIDUES) + [expr $array(NNUCLEOTIDES) * 2]]
	} else {
		set nresidues $array(NRESIDUES)
	}
	#puts "nresidues = $nresidues"

	# Run WILSON program
	set output [exec wilson HKLIN $input_mtz << "TITLE RUN FROM GETWILSONVALUES.SH\nWILSON\nNRESIDUES $nresidues\nLABIN FP=$fp SIGFP=$sigfp"]
	#puts $output

	if { ![regexp {.*occupied by atoms *= *([-0-9.]*).*} $output full atoms] } {
		puts "Search string not found"
	}

	if { ![regexp {.*line gives: *B *= *([-0-9.]*).*} $output full bfactor] } {
		puts "Search string not found"
	}

	if { ![info exists atoms] } {
		puts "Could not find \"occupied by atoms\" line.  Exitting\n"
		exit
	}

	if { ![info exists bfactor] } {
		puts "Could not find \"occupied by atoms\" line.  Exitting\n"
		exit
	}

	set solvent_content [expr 1.0 - $atoms]

	#puts "solvent=$solvent_content\tbfactor=$bfactor"
	set array(BFACTOR) $bfactor
	set array(SOLVENT_CONTENT) $solvent_content
}

# 
# CCP4i - Start a Crank run
#
proc crank_run { arrayname } {
	upvar #0 $arrayname array
	global Capabilities

	set array(INPUT_FILES) "HKLIN"
	set array(OUTPUT_FILES) "HKLOUT"

	#   #
	#   # Check that all obligatory fields in the interface are filled in
	#   #
	#   if { ![StringSame $array(FIND_MODE) "User Input"] } {
	# 	  if { $array(ATOM_NAME) == "" } {
	# 		  WarningMessage "No Atom Name Entered\nPlease enter an Atom Name"
	# 		  return 0
	# 	  }

	# 	  if { $array(NATOMS) == "" } {
	# 		  WarningMessage "Number of Atoms not entered\nPlease enter number of Atoms"
	# 		  return 0
	# 	  }
	#   }

	#   if { $array(BFACTOR) == "" } {
	# 	  WarningMessage "B-Factor not entered\nPlease enter b-factor"
	# 	  return 0
	#   }

	#   if { $array(SOLVENT_CONTENT) == "" } {
	# 	  WarningMessage "Solvent Content not entered\nPlease enter Solvent Content"
	# 	  return 0
	#   }

	#   if { $array(NRESIDUES) == "" || $array(NNUCLEOTIDES) == ""} {
	# 	  WarningMessage "Please enter both number of residues and number of nucleotides\n"
	# 	  return 0
	#   }

	#   if { $array(NRESIDUES) == 0 && $array(NNUCLEOTIDES) == 0} {
	# 	  WarningMessage "Please enter both number of residues and number of nucleotides\nEither, but not both can be zero"
	# 	  return 0
	#   }

	#   if { $array(NRESIDUES) < 0 } {
	# 	  WarningMessage "Number of residues must be greater than 0"
	# 	  return
	#   }

	#   if { $array(NNUCLEOTIDES) < 0 } {
	# 	  WarningMessage "Number of nucleotides must be greater than 0"
	# 	  return
	#   }

	#   if { $array(SAD_F_PLUS) == "" || $array(SAD_SIGF_PLUS) == "" } {
	# 	  WarningMessage "Please enter both FP+ and SIGFP+ columns"
	# 	  return 0
	#   }

	#   if { $array(SAD_F_MINUS) == "" || $array(SAD_SIGF_MINUS) == "" } {
	# 	  WarningMessage "Please enter both FP+ and SIGFP+ columns"
	# 	  return 0
	#   }

	#   if { $array(SAD_I_PLUS) == "" || $array(SAD_SIGI_PLUS) == "" } {
	# 	  WarningMessage "Please enter both IP+ and SIGIP+ columns"
	# 	  return 0
	#   }

	#   if { $array(SAD_I_MINUS) == "" || $array(SAD_SIGI_MINUS) == "" } {
	# 	  WarningMessage "Please enter both IP+ and SIGIP+ columns"
	# 	  return 0
	#   }

	#   #
	#   # A common error is to set both F+ and F- to F+.  Check for that here.
	#   # 
	#   if { [StringSame $array(CRANK_EXPERIMENT) SAD] } {
	# 	  if { [StringSame $array(INPUT_TYPE) AMPLITUDES] || [StringSame $array(INPUT_TYPE) ALL] } {
	# 		  if { [StringSame $array(SAD_F_PLUS) $array(SAD_F_MINUS)] } {
	# 			  WarningMessage "You have set both the F+ and F- columns to $array(SAD_F_PLUS).\nIn order to run SAD, you need both F+ and F- Friedel mates"
	# 			  return 0
	# 		  }
	# 	  }

	# 	  if { [StringSame $array(INPUT_TYPE) INTENSITIES] || [StringSame $array(INPUT_TYPE) ALL] } {
	# 		  if { [StringSame $array(SAD_I_PLUS) $array(SAD_I_MINUS)] } {
	# 			  WarningMessage "You have set both the I+ and I- columnns to $array(SAD_I_PLUS).\nIn order to run SAD, you need both I+ and I- Friedel mates"
	# 			  return 0
	# 		  }
	# 	  }
	#   }

	#   if { [StringSame $array(FIND_MODE) CRUNCH2] } {
	# 	  if { $array(CRUNCH2_DREAR_NUM_C) == "" || $array(CRUNCH2_DREAR_NUM_N) == "" || $array(CRUNCH2_DREAR_NUM_O) == "" || $array(CRUNCH2_DREAR_NUM_S) == "" || $array(CRUNCH2_DREAR_NUM_P) == "" } {
	# 		  WarningMessage "Please enter number of all atom types"
	# 		  return 0
	# 	  }
	#   }

	#   #
	#   # Check information to go into <dataset_info> section
	#   # 
	
	#   # If we are running CRUNCH2, we need to be looking for at least 3 atoms
	#   #
	#   #
	#   # The old way to do this was to tell the user to increase the number
	#   # of atoms to look for.  Since SHELXD will look for more atoms than
	#   # you tell it to, I figure that we can just ask Crunch2 to look for
	#   # 3 atoms.  This strategy works in a number of test cases.
	#   #
	#   if { [StringSame $array(FIND_MODE) CRUNCH2] && $array(NATOMS) < 3 } {
	# 	  set array(NATOMS) 3
	# # 	  WarningMessage "Sorry, CRUNCH2 needs to look for at least 3 atoms.\n\nPlease increase Number of Atoms"
	# # 	  return 0
	#   }

	#   # Check validity solvent content
	#   if { $array(SOLVENT_CONTENT) < 0.0 || $array(SOLVENT_CONTENT) > 1.0 } {
	# 	  WarningMessage "Solvent content must be between 0.0 and 1.0."
	# 	  return 0
	#   }

	#   if { $array(BFACTOR) < 0.0 || $array(BFACTOR) > 200.0 } {
	# 	  WarningMessage "B-factor must be between 0.0 and 200.0"
	# 	  return 0
	#   }

	#   # Incorrect atom name
	#   #
	#   # Later, need to check to make sure all atom names are correct if
	#   # the user is inputting them by hand instead of having a
	#   # substructure determination program find them.
	#   #
	#   if { ![StringSame $array(FIND_MODE) "User Input"] } {
	# 	  if { [GoodAtomName $arrayname] == 0 } {
	# 		  WarningMessage "Incorrect atom name:\n\nPlease choose a valid CCP4\natom name from \$CLIBD/sfatom.lib"
	# 	  }
	#   }


	#
	# Setup the names for the output columns for each step
	# (This is very simple, and is just because we can't generate the
	#  proper string in crank.com to correspond to, for example: 1_SCALEIT_F_0)
	#
	# For even more simplicity, we assign all of these, even though most
	# programs only output a few of these.  We handle the different
	# cases in crank.com.
	#
	for { set i 1 } { $i <= $array(N_PROGRAMS) } { incr i } {
		set array(OUTPUT_EXPERIMENTAL_COLUMNS,$i) [join "$i $array(PROGRAM_NAME,$i)" _]
		set array(OUTPUT_F_COLUMNS,$i) [join "$i $array(PROGRAM_NAME,$i)" _]
		set array(OUTPUT_EVALUE_COLUMNS,$i) [join "$i $array(PROGRAM_NAME,$i)" _]
		set array(OUTPUT_FA_COLUMNS,$i) [join "$i $array(PROGRAM_NAME,$i)" _]
		set array(OUTPUT_ALPHA_COLUMNS,$i) [join "$i $array(PROGRAM_NAME,$i)" _]
		set array(OUTPUT_PHASE_COLUMNS,$i) [join "$i $array(PROGRAM_NAME,$i)" _]
		set array(OUTPUT_HL_COLUMNS,$i) [join "$i $array(PROGRAM_NAME,$i)" _]
	}


	# Calculate the total number of datasets for the .com files
	set total 0
	for { set i 0 } { $i < $array(N_CRYSTALS) } { incr i } {
		for { set j 0 } { $j < $array(N_DATA,$i) } { incr j } {
			set total [expr $total + 1]
		}
	}
	set array(TOTAL_DATASETS) $total
	#puts "total_datasets = $total"

	#
	# Loop over all OTHERCOLUMN columns, making standard and unique names
	# to map the user-named input columns.
	#
	for { set i 1 } { $i <= $array(N_OTHERCOLUMN) } { incr i } {
		if { [string compare $array(OTHERCOLUMN_TYPE,$i) "F columns"] == 0 } {
			set array(OTHERCOLUMN_NEWLABEL_F,$i) [join "OTHER $i _F_F" ""]
			set array(OTHERCOLUMN_NEWLABEL_SIGF,$i) [join "OTHER $i _F_SIGF" ""]
		}
		if { [string compare $array(OTHERCOLUMN_TYPE,$i) "Phase columns"] == 0 } {
			set array(OTHERCOLUMN_NEWLABEL_FB,$i) [join "OTHER $i _PHASE_FB" ""]
			set array(OTHERCOLUMN_NEWLABEL_PHIB,$i) [join "OTHER $i _PHASE_PHIB" ""]
			set array(OTHERCOLUMN_NEWLABEL_FOM,$i) [join "OTHER $i _PHASE_FOM" ""]
		}
		if { [string compare $array(OTHERCOLUMN_TYPE,$i) "HL columns"] == 0 } {
			set array(OTHERCOLUMN_NEWLABEL_HLA,$i) [join "OTHER $i _HL_HLA" ""]
			set array(OTHERCOLUMN_NEWLABEL_HLB,$i) [join "OTHER $i _HL_HLB" ""]
			set array(OTHERCOLUMN_NEWLABEL_HLC,$i) [join "OTHER $i _HL_HLC" ""]
			set array(OTHERCOLUMN_NEWLABEL_HLD,$i) [join "OTHER $i _HL_HLD" ""]
		}
		if { [string compare $array(OTHERCOLUMN_TYPE,$i) "E-value columns"] == 0 } {
			set array(OTHERCOLUMN_NEWLABEL_E,$i) [join "OTHER $i _EVALUE_E" ""]
			set array(OTHERCOLUMN_NEWLABEL_SIGE,$i) [join "OTHER $i _EVALUE_SIGE" ""]
		}
		if { [string compare $array(OTHERCOLUMN_TYPE,$i) "FA columns"] == 0 } {
			set array(OTHERCOLUMN_NEWLABEL_FA,$i) [join "OTHER $i _FA_FA" ""]
			set array(OTHERCOLUMN_NEWLABEL_SIGFA,$i) [join "OTHER $i _FA_SIGFA" ""]
		}
		if { [string compare $array(OTHERCOLUMN_TYPE,$i) "Alpha columns"] == 0 } {
			set array(OTHERCOLUMN_NEWLABEL_ALPHA,$i) [join "OTHER $i _ALPHA_ALPHA" ""]
		}
	}

	#
	# Loop over all the OTHERDATA elements making labels for each
	# element.
	#
	set num_substructures 0
	set num_protein_models 0
	set num_sequences 0
	set num_maps 0
	set num_freers 0
	for { set i 1 } { $i <= $array(N_OTHERDATA) } { incr i } {
		set type $array(OTHERDATA_TYPE,$i)
		if { [string compare $type "Substructure"] == 0 } {
			incr num_substructures
			set array(OTHERDATA_LABEL,$i) "SUBSTRUCTURE$num_substructures"
		} elseif { [string compare $type "Protein Model"] == 0 } {
			incr num_protein_models
			set array(OTHERDATA_LABEL,$i) "PROTEIN_MODEL$num_protein_models"
		} elseif { [string compare $type "Sequence"] == 0 } {
			incr num_sequences
			set array(OTHERDATA_LABEL,$i) "SEQUENCE$num_sequences"
		} elseif { [string compare $type "Map"] == 0 } {
			incr num_maps
			set array(OTHERDATA_LABEL,$i) "MAP$num_maps"
		} elseif { [string compare $type "Freer flag"] == 0 } {
			incr num_freers
			set array(OTHERDATA_LABEL,$i) "FREER$num_freers"
		}
	}

	return 1
}


#
# CCP4i - Setup variables and menus at the start of a run
#
proc crank_setup { typedefVar arrayname } {
	global experimental_columns
	global f_columns
	global last_f_column	
	global phase_columns
	global hl_columns
	global evalue_columns
	global fa_columns
	global alpha_columns
	global substructures
	global protein_models
	global sequences
	global maps
	global freer

	global Capabilities 
	upvar #0 $typedefVar typedef
	upvar #0 $arrayname array

#	check_all_executables

    # The type of each dataset
    DefineMenu _data_type [list "SAD" \
							   "Derivative" \
							   "Peak" \
                               "Inflection" \
                               "High Remote" \
                               "Low Remote" \
                               "Other" ] \
		[list SAD DERIVATIVE PEAK INFL HREM LREM OTHER]

    # The type of each non-experimental
    DefineMenu _othercolumn_type [list "None" \
									"F columns" \
									"Phase columns" \
									"HL columns" \
									"E-value columns" \
									"FA columns" \
									"Alpha columns" ] \
		[list NONE F_COLUMNS PHASE_COLUMNS HL_COLUMNS EVALUE_COLUMNS \
			 FA_COLUMNS ALPHA_COLUMNS]

    # The type of each non-experimental
    DefineMenu _otherdata_type [list "None" \
									"Substructure" \
									"Protein Model" \
									"Sequence" \
									"Map" \
									"Freer flag" ] \
		[list NONE SUBSTRUCTURE PROTEIN_MODEL SEQUENCE MAP FREER ]
	
	# The type of experiment we are going to perform SAD, MAD, MIR(AS), SIR(AS), etc.
	# Could have subtypes in here later for "Halide Soak", or could be a different menu
 	DefineMenu _crank_experiment [list "SAD" \
									  "SIR" \
									  "MIR" \
									  "MAD" ] \
 		[list SAD SIR MIR MAD]

	DefineMenu _input_type [list "Intensities (I+/I-)" \
								"Amplitudes (F+/F-)" \
								"Amplitudes (F + DANO)" \
								"ALL" ] \
		[list INTENSITIES AMPLITUDES AMPLITUDES_DANO ALL]

    DefineMenu _arpwarp_ref_mode [list "Fast" \
									  "Slow"] \
		[list REFFAST REFSLOW ]


 	DefineMenu _arpwarp_freer [list "do not use"  \
								   "use"] \
 		[list N Y]

	DefineMenu _arpwarp_phase_restrain [list "SAD/SIR" \
											"No" \
											"PHIB/FOM" \
											"HL" ] \
		[list SADSIR N Y HL]
	
	DefineMenu _arpwarp_scale [list "BULK" "SIMPLE"] \
		[list BULK SIMPLE]

	DefineMenu _arpwarp_scanis [list "isotropic" "aniostropic"] \
		[list N Y]

    DefineMenu _arpwarp_ppin [list "SAD" \
								  "SIR" \
								  "NO" \
								  "MLHL"] \
		[list SAD SIR NO MLHL]

    DefineMenu _arpwarp_refmac_ref_set [list "working" \
											"free"] \
		[list N Y]

    DefineMenu _experimental_program [list "Program : SCALEIT" \
										  "Program : AFRO" \
										  "Program : PMF" \
										  "Program : CRUNCH2" \
										  "Program : BP3" \
										  "Program : DM" \
										  "Program : RESOLVE" \
 										  "Program : SHELXC" \
 										  "Program : SHELXD" \
 										  "Program : SHELXE" \
										  "Decision" \
										 ] \
		[list SCALEIT AFRO PMF CRUNCH2 BP3 DM RESOLVE SHELXC SHELXD SHELXE]


#     DefineMenu _experimental_program [list "Program : SCALEIT" \
# 										  "Program : FHSCAL" \
# 										  "Program : SCALEIT_ANALYSE" \
# 										  "Program : PREPHADATA" \
# 										  "Program : DREAR" \
# 										  "Program : AFRO" \
# 										  "Program : PMF" \
# 										  "Program : CRUNCH2" \
# 										  "Program : RANTAN" \
# 										  "Program : BP3" \
# 										  "Program : MLPHARE" \
# 										  "Program : DM" \
# 										  "Program : SOLOMON" \
# 										  "Program : PIRATE" \
# 										  "Program : RESOLVE" \
# 										  "Program : MAID" \
# 										  "Program : FFFEAR" \
# 										  "Program : ARPWARP" \
# 										  "Program : REFMAC" \
# 										  "Program : REFMAC5D" \
# 										  "Program : SFCHECK" \
# 										  "Program : PROCHECK" \
# 										  "Program : Xfit" \
# 										  "Program : O" \
# 										  "Program : Pymol" \
# 										  "Program : CCP4mg" \
# 										  "Program : COOT" \
# 										  "Decision" \
# 										 ] \
# 		[list SCALEIT FHSCAL SCALEIT_ANALYSE \
# 			 PREPHADATA DREAR AFRO SHELXC \
# 			 PMF CRUNCH2 SHELXD RANTAN \
# 			 BP3 MLPHARE \
# 			 DM SOLOMON SHELXE PIRATE RESOLVE \
# 			 MAID FFFEAR ARPWARP \
# 			 REFMAC REFMAC5D SFCHECK PROCHECK \
# 			 XFIT O PYMOL CCP4MG COOT DECISION]

	DefineMenu _program_variables [list "R-factor" \
									   "R-free" \
									   "CRUNCH2 Score" \
									   "SHELXD CC(all)" \
									   "SHELXD CC(weak)" \
									   "BP3 FOM" \
									   "SOLOMON FOM" \
									   "DM FOM" \
									   "ARPWARP FOM" \
									   "Average B-Factor" \
									   "Number of Residues found" \
									  ] \
		[list VAR1 VAR2 VAR3 VAR4 VAR5 VAR6 VAR7 VAR8 VAR9 VAR10 VAR11]

	DefineMenu _program_equalities [list "= (equals)" \
										"> (is greater than)" \
										"< (is less than)" \
										">= (is greater than or equals)" \
										"<= (is less than or equals)" \
										"! (is not)" \
									   ] \
		[list EQUALS GREATER_THAN LESSER_THAN \
			 GREATER_THAN_OR_EQUALS LESSER_THAN_OR_EQUALS \
			 IS_NOT]

	DefineMenu _program_outcomes [list "STOP" \
									  "CONTINUE" \
									  "GO TO STEP" \
									 ] \
		[list STOP CONTINUE GOTO_STEP]


	DefineMenu _scaleit_scale_refine_mode [list "scale only" \
											   "scale & isotropic Bfactor" \
											   "scale & anisotropic Bfactor" \
											  ] \
		[list "SCALE" "ISOTROPIC" "ANISOTROPIC"]

	DefineMenu  _rantan_mode [list "FASTAN" \
								  "weighted tangent formula" ] \
		[list  FASTAN SWTR ]

	DefineMenu _check_data [list "native Fs" \
								"anomalous Fs" \
								"native Is" \
								"anomalous Is"] \
		[list SF SF_ANOM I I_ANOM]

	DefineMenu _check_sfcheck_mode [list "structure against experimental data" \
										"experimental data only" \
										"structure only"] \
		[list BOTH EXPERIMENT STRUCTURE]
									

	DefineMenu _resolve_build_mode [list "Default" \
										"Superquick" \
										"Quick" \
										"Thorough" ] \
		[list DEFAULT SUPERQUICK QUICK THOROUGH]


	#
	# Setup variable menus
	#

	# varmenu for the datasets that have been entered so far
 	set typedef(_input_experimental_columns) { varmenu INPUT_EXPERIMENTAL_COLUMNS_LIST INPUT_EXPERIMENTAL_COLUMNS_ALIAS 20 }
 	set typedef(_input_f_columns) { varmenu INPUT_F_COLUMNS_LIST INPUT_F_COLUMNS_ALIAS 20 }
 	set typedef(_input_evalue_columns) { varmenu INPUT_EVALUE_COLUMNS_LIST INPUT_EVALUE_COLUMNS_ALIAS 20 }
 	set typedef(_input_fa_columns) { varmenu INPUT_FA_COLUMNS_LIST INPUT_FA_COLUMNS_ALIAS 20 }
 	set typedef(_input_alpha_columns) { varmenu INPUT_ALPHA_COLUMNS_LIST INPUT_ALPHA_COLUMNS_ALIAS 20 }
 	set typedef(_input_phase_columns) { varmenu INPUT_PHASE_COLUMNS_LIST INPUT_PHASE_COLUMNS_ALIAS 20 }
 	set typedef(_input_hl_columns) { varmenu INPUT_HL_COLUMNS_LIST INPUT_HL_COLUMNS_ALIAS 20 }
 	set typedef(_input_substructures) { varmenu INPUT_SUBSTRUCTURES_LIST INPUT_SUBSTRUCTURES_ALIAS 20 }
 	set typedef(_input_protein_models) { varmenu INPUT_PROTEIN_MODELS_LIST INPUT_PROTEIN_MODELS_ALIAS 20 }
 	set typedef(_input_sequences) { varmenu INPUT_SEQUENCES_LIST INPUT_SEQUENCES_ALIAS 20 }
 	set typedef(_input_maps) { varmenu INPUT_MAPS_LIST INPUT_MAPS_ALIAS 20 }
 	set typedef(_input_freer) { varmenu INPUT_FREER_LIST INPUT_FREER_ALIAS 20 }

  set typedef(_testmenu) { varmenu INPUT_TEST_LIST INPUT_TEST_ALIAS 8 }

	set experimental_columns {}
	set f_columns {}
	set last_f_column {}
	set phase_columns {}
	set hl_columns {}
	set evalue_columns {}
	set fa_columns {}
	set alpha_columns {}
	set substructures {}
	set protein_models {}
	set sequences {}
	set maps {}
	set freer {}

	return 1
}

#
# CCP4i - Draw main Crank task window
#
proc crank_task_window { arrayname } {
	upvar #0 $arrayname array
	global env
	global test
	
	if { ![CreateTaskWindow $arrayname  \
			   "CRANK" CRANK \
			   [list "Required parameters" \
					"Experimental Pipeline" \
				   ] ] }  { return 0 }

 	set required_folder 1
	set experiment_folder 2

	# Retrive defaults from XML file if available & requested
	source [SearchPath TOP utils xml_utils.tcl]

	# Populate the task window
	OpenFolder protocol

	# Title frame, a cute one with a picture
	OpenSubFrame frame1

	# The picture, on the left
 	set cranklogo [image create photo -file [ FileJoin $env(CRANK) bin crank-logo.gif ] ]
 	set logo [label $frame1.f1 -image $cranklogo]
 	pack $logo -side left

 	CreateLine line \
 		message "Enter a title for this job (TITLE)" \
 		label "Title" \
 		widget TITLE -width 80 \
 		button "Test" \
 		-command "debug_output_all_vars $arrayname"

	CreateInputFileLine line \
		"Enter input MTZ file name (HKLIN)" \
		"MTZ in" \
		HKLIN DIR_HKLIN \
		-fileout HKLOUT DIR_HKLOUT _crank_ \
		-setlabin FREER_LABEL [list FREE FreeR FreeR_flag] \
        -setfileparam resolution_max HIGH_RES_LIMIT \
        -setfileparam resolution_min LOW_RES_LIMIT \
		-command "runhighrescutoff $arrayname"

	CreateOutputFileLine line \
		"Enter output MTZ file name (HKLOUT)" \
		"MTZ out" \
		HKLOUT DIR_HKLOUT \
		-toggle_display CRANK_MODE open [list FIND_REFINE FIND_REFINE_DM FIND_REFINE_DM_MODEL ]

 	pack $line -side top

	CloseSubFrame

	OpenFolder file


	#
	# Experimental columns
	#
	OpenSubFrame frame_new -toggle_display TOGGLE_INPUT_EXP_COLUMNS open 1

	CreateToggleFrame N_CRYSTALS crystal_proc \
        "Add new Crystals/Datasets" \
		"Crystal #" \
        "Add new Crystals/Datasets" \
		[list  CRYSTAL_ID \
			 N_DATA \
 			 CRYSTAL_ATOM_NAME \
 			 CRYSTAL_N_ATOMS \
			 CRYSTAL_INPUT_SUBSTRUCTURE \
			 CRYSTAL_SUBSTRUCTURE_INPUT_COORDSIN \
			 CRYSTAL_SUBSTRUCTURE_DIR_INPUT_COORDSIN \
			 DATA_TYPE \
 			 DATA_CUKALPHA \
 			 DATA_FPRIME \
 			 DATA_FPRIMEPRIME \
 			 DATA_WAVELENGTH \
 			 DATA_ANOMALOUS \
			 DATA_I \
			 DATA_SIGI \
			 DATA_I_PLUS \
			 DATA_SIGI_PLUS \
			 DATA_I_MINUS \
			 DATA_SIGI_MINUS \
			] \
		-child data_proc

	CloseSubFrame 

	#
	# Other Columns of data from the input .mtz file
	#
	CreateExtendingFrame N_OTHERCOLUMN othercolumn_proc \
        "Add a new set of columns from the .MTZ file (F, Phase, HL, etc)" \
        "Add Other Column" \
		[list OTHERCOLUMN_TYPE \
			 OTHERCOLUMN_F \
			 OTHERCOLUMN_SIGF \
			 OTHERCOLUMN_FB \
			 OTHERCOLUMN_PHIB \
			 OTHERCOLUMN_FOM \
			 OTHERCOLUMN_HLA \
			 OTHERCOLUMN_HLB \
			 OTHERCOLUMN_HLC \
			 OTHERCOLUMN_HLD \
			 OTHERCOLUMN_E \
			 OTHERCOLUMN_SIGE \
			 OTHERCOLUMN_FA \
			 OTHERCOLUMN_SIGFA \
			 OTHERCOLUMN_ALPHA \
			]

	#
	# Other sources of data (protein model, substructure, sequence, etc.)
	#
	CreateExtendingFrame N_OTHERDATA otherdata_proc \
		"Define Other source of Input data (Substructure, Protein model, Sequence, etc.)" \
		"Add other data" \
		[list OTHERDATA_TYPE \
			 OTHERDATA_SUBSTRUCTURES \
			 OTHERDATA_PROTEIN_MODELS \
			 OTHERDATA_SEQUENCES \
			 OTHERDATA_MAPS \
			 OTHERDATA_FREER \
			 DIR_INPUT_COORDSIN \
			 DIR_INPUT_XYZIN \
			 DIR_SEQIN \
			 DIR_MAPIN \
			 FREER_LABEL \
			]


	#
	# Output
	#

	# 	CreateOutputFileLine line \
		#         "Output substructure coordinate file (COORDSOUT)" \
		#         "Substructure out" \
		#         COORDSOUT DIR_COORDSOUT

	# 	CreateOutputFileLine line \
		#         "Output coordinate file (XYZOUT)" \
		#         "PDB out" \
		#         XYZOUT DIR_XYZOUT


	OpenFolder $required_folder

	OpenSubFrame frame -toggle_display NUCLEOTIDES_PRESENT open 1

	CreateLine line \
		label "Macromolecule:" -italic \
		message "Number of Protein Residues - One or both of number of residues and nucleotides must be specified" \
		label "Num. Protein Residues:" \
		widget NRESIDUES -oblig \
		message "Number of Nucleotides  - One or both of number of residues and nucleotides must be specified" \
		label "Num. Nucleotides:" \
		widget NNUCLEOTIDES -oblig \
		label "DNA/RNA present" \
		message "DNA/RNA present" \
		widget NUCLEOTIDES_PRESENT

	CloseSubFrame

	OpenSubFrame frame -toggle_display NUCLEOTIDES_PRESENT open 0

	CreateLine line \
		label "Macromolecule:" -italic \
		message "Number of Protein Residues - One or both of number of residues and nucleotides must be specified" \
		label "Num. Protein Residues:" \
		widget NRESIDUES -oblig \
		label "DNA/RNA present" \
		message "DNA/RNA present" \
		widget NUCLEOTIDES_PRESENT

	CloseSubFrame

	# Input F columns (F and sigF) from MTZ file
 	CreateLabinLine line \
 		"F columns for Wilson program" \
 		HKLIN "Wilson F" WILSON_F {} \
 		-sigma "Wilson SIGF" WILSON_SIGF {}

	CreateLine line \
  		message "B-factor - Can calculate this from input .mtz via Wilson Plot - Use Calculate B and Solv. Content button" \
  		label "B-factor" \
  		widget BFACTOR -oblig \
		toggle_display CRANK_MODE open [list FIND_REFINE FIND_REFINE_DM FIND_REFINE_DM_MODEL] \
 		message "Solvent Content - Can calculate this from input .mtz via Wilson Plot - Use Calculate B and Solv. Content button" \
 		label "Solvent Content" \
 		widget SOLVENT_CONTENT -oblig \
		toggle_display CRANK_MODE open [list FIND_REFINE_DM FIND_REFINE_DM_MODEL] \
		message "Calculate b-factor and solvent content from the Wilson plot - First dataset in the first crystal will be used" \
		button "Calculate B and Solv. Content" \
		-command "runwilson $arrayname"

	#	OpenSubFrame frame_crunch2 -toggle_display FIND_MODE open [list CRUNCH2]
	#
	# 	CreateLine line \
		# 		message "Enter the number of light atoms in the asymmetric unit" \
		# 		label "Number of atoms in asymmetric unit:" \
		# 		message "Number of carbon atoms in the asymmetric unit" \
		# 		label "C" \
		# 		widget TOTAL_NUM_C -oblig \
		# 		message "Number of nitrogen atoms in the asymmetric unit" \
		# 		label "N" \
		# 		widget TOTAL_NUM_N -oblig \
		# 		message "Number of oxygen atoms in the asymmetric unit" \
		# 		label "O" \
		# 		widget TOTAL_NUM_O -oblig \
		# 		message "Number of sulphur atoms in the asymmetric unit" \
		# 		label "S" \
		# 		widget TOTAL_NUM_S -oblig \
		# 		message "Number of phosphorus atoms in the asymmetric unit" \
		# 		label "P" \
		# 		widget TOTAL_NUM_P -oblig \
		# 		button "Calc" \
		# 		-command "calculate_from_contents $arrayname"
	#
	#	CloseSubFrame

	OpenFolder $experiment_folder

	CreateLine line \
		label "Program to run or Decision to take:" \
		message "Add which program or decision as the next step in the experiment" \
		widget EXPERIMENTAL_PROGRAM \
		label "                                " \
 		button "Clear Pipeline" \
 		-command "clear_pipeline $arrayname" \
 		button "Default Pipeline" \
 		-command "default_pipeline $arrayname"

 	CreateToggleFrame N_PROGRAMS experiment_proc \
		"Define Experiment" \
		"Step \#" \
		"Add Program/Decision" \
 		[list PROGRAM_NAME \
 			 NBINS \
			 SCALEIT_REFINE_MODE \
			 PREPHADATA_USE_REVISE_RESO_CUTOFF \
			 PREPHADATA_REVISE_RESOLUTION_MAX \
			 PREPHADATA_EXCLUDE_RESOLUTION \
			 PREPHADATA_EXCLUDE_RESOLUTION_MIN \
			 PREPHADATA_EXCLUDE_RESOLUTION_MAX \
			 PREPHADATA_RISO \
			 PREPHADATA_RANO \
			 PREPHADATA_SIGM \
			 PREPHADATA_ECALC_EXCLUDE_CENTRIC \
			 PREPHADATA_ECALC_EXCLUDE_SIGP \
			 PREPHADATA_ECALC_EXCLUDE_SIGPH \
			 PREPHADATA_ECALC_EXCLUDE_FPMAX \
			 PREPHADATA_ECALC_EXCLUDE_FPHMAX \
			 PREPHADATA_ECALC_EXCLUDE_DIFF \
			 AFRO_RESOLUTION_MIN \
			 AFRO_RESOLUTION_MAX \
			 AFRO_SIGF \
			 AFRO_SANO \
			 AFRO_BINS \
			 AFRO_INTERPOLATE \
			 DREAR_LOCAL_SCALING \
			 DREAR_CUTOFF \
			 DREAR_TMAX \
			 DREAR_XMIN \
			 DREAR_YMIN \
			 DREAR_ZMAX \
			 DREAR_ZMIN \
			 RANTAN_NOUT \
			 RANTAN_SWTR \
			 RANTAN_IFEMAX \
			 RANTAN_EMAX \
			 RANTAN_EMIN \
			 RANTAN_WFOM \
			 RANTAN_WABS \
			 RANTAN_WPSI \
			 RANTAN_WRES \
			 RANTAN_THRESHHOLD \
			 RANTAN_EXCLUDE_RESOLUTION \
			 RANTAN_EXCLUDE_RESOLUTION_MIN \
			 RANTAN_EXCLUDE_RESOLUTION_MAX \
			 DM_F \
			 DM_SIGF \
			 SOLOMON_F \
			 SOLOMON_SIGF \
			 RESOLVE_MASK_CYCLES \
			 RESOLVE_MINOR_CYCLES \
			 RESOLVE_NO_BUILD \
			 RESOLVE_BUILD_MODE \
			 RESOLVE_PRIME_AND_SWITCH \
			 RESOLVE_CUT_UP_MODEL \
			 RESOLVE_CC_RATIO \
			 RESOLVE_USE_INPUT_SOLVENT \
			 RESOLVE_HIGH_RES_CUTOFF \
			 RESOLVE_LOW_RES_CUTOFF \
			 ARPWARP_REF_MODE \
			 ARPWARP_FREER \
			 ARPWARP_SCALE \
			 ARPWARP_SCANIS \
			 ARPWARP_REFMAC_REF_SET \
			 ARPWARP_PHASE_RESTRAIN \
			 SFCHECK_MODE \
			 SFCHECK_DATA \
			 PROGRAM_VARIABLES \
			 PROGRAM_EQUALITIES \
			 PROGRAM_OUTCOMES \
			 INPUT_EXPERIMENTAL_COLUMNS \
			 INPUT_EXPERIMENTAL_COLUMNS_LIST \
			 INPUT_EXPERIMENTAL_COLUMNS_ALIAS \
			 INPUT_F_COLUMNS \
			 INPUT_F_COLUMNS_LIST \
			 INPUT_F_COLUMNS_ALIAS \
			 INPUT_PHASE_COLUMNS \
			 INPUT_PHASE_COLUMNS_LIST \
			 INPUT_PHASE_COLUMNS_ALIAS \
			 INPUT_HL_COLUMNS \
			 INPUT_HL_COLUMNS_LIST \
			 INPUT_HL_COLUMNS_ALIAS \
			 INPUT_EVALUE_COLUMNS \
			 INPUT_EVALUE_COLUMNS_LIST \
			 INPUT_EVALUE_COLUMNS_ALIAS \
			 INPUT_SUBSTRUCTURES \
			 INPUT_SUBSTRUCTURES_LIST \
			 INPUT_SUBSTRUCTURES_ALIAS \
			 INPUT_SEQUENCES \
			 INPUT_SEQUENCES_LIST \
			 INPUT_SEQUENCES_ALIAS \
			 INPUT_PROTEIN_MODELS \
			 INPUT_PROTEIN_MODELS_LIST \
			 INPUT_PROTEIN_MODELS_ALIAS \
 			] \
		-justify left


}


