#CCP4I SCRIPT TEMPLATE crank

#
# crank_prepare.com
#
# This file generates the XML input needed for crank_prepare.tcl.
# crank_prepare.tcl takes the MTZ file input by the user and fills in
# all the missing columns.  For instance, if the user input I+ and I-,
# crank_prepare.tcl would generate the F+, F-, Fmean and DANO columns.
#
# sness - In the current version, crank_prepare.com just renames
# the input columns to the output columns, taking names from the
# CCP4i interface and renaming them to things like 
#    INPUT_F_0
#  and
#    INPUT_FB 
#

1 <?xml version="1.0" standalone="yes"?>
1 <crank>
#
# Dataset descriptors from interface
#
1 <dataset_info>
1	<description>$TITLE</description>
1   <code>crank</code>
1 	<solvent_content>$SOLVENT_CONTENT</solvent_content>
1 	<residues>$NRESIDUES</residues>
IF { $NUCLEOTIDES_PRESENT }
1 	<nucleotides>$NNUCLEOTIDES</nucleotides>
ELSE
1   <nucleotides>0</nucleotides>
ENDIF
1   <atom_name>$ATOM_NAME</atom_name>
1   <natoms>$NATOMS</natoms>
1	<bfactor>$BFACTOR</bfactor>
1   <all_atoms>
1       <c>$TOTAL_NUM_C</c>
1       <n>$TOTAL_NUM_N</n>
1       <o>$TOTAL_NUM_O</o>
1       <s>$TOTAL_NUM_S</s>
1       <p>0</p>
1   </all_atoms>
1 </dataset_info>
1

1 <soap>
1 	<run>
1 		<mtz_in>
1 			<filename>$HKLIN</filename>
1			<input_data>$INPUT_TYPE</input_data>
1		    <freer_label>$FREER_LABEL</freer_label>
1 			<n_datasets>$N_DATASETS</n_datasets>


#######################
#   MTZ input names   #
#######################

#
# Input Experimental Columns
#
1			<exp_columns>
LOOP K 1 $N_CRYSTALS
1		<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1			<type>NATIVE</type>
1				<i>$DATA_I($K)</i>
1				<sigi>$DATA_SIGI($K)</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1			<data id="$M">
1				<type>$DATA_TYPE($K,$M)</type>
IF !$DATA_ANOMALOUS($K,$M)
1				<i>$DATA_I($K,$M)</i>
1				<sigi>$DATA_SIGI($K,$M)</sigi>
ELSE
1				<i_plus>$DATA_I_PLUS($K,$M)</i_plus>
1				<sigi_plus>$DATA_SIGI_PLUS($K,$M)</sigi_plus>
1				<i_minus>$DATA_I_MINUS($K,$M)</i_minus>
1				<sigi_minus>$DATA_SIGI_MINUS($K,$M)</sigi_minus>
ENDIF
1				<wavelength>$DATA_WAVELENGTH($K,$M)</wavelength>
1				<anomalous>$DATA_ANOMALOUS($K,$M)</anomalous>
1			</data>
ENDLOOP
ENDIF
1		</crystal>
ENDLOOP
1			  </exp_columns>

#
# Input Other Data columns (F, Phase, HL, etc)
#
LOOP K 1 $N_OTHERCOLUMN
1		<othercolumn id="$K">
1           <type>$OTHERCOLUMN_TYPE($K)</type>
IF { [StringSame $OTHERCOLUMN_TYPE($K) F_COLUMNS] }
1			<f>$OTHERCOLUMN_F($K)</f>
1			<sigf>$OTHERCOLUMN_SIGF($K)</sigf>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) PHASE_COLUMNS] }
1			<fb>$OTHERCOLUMN_FB($K)</fb>
1			<phib>$OTHERCOLUMN_PHIB($K)</phib>
1			<fom>$OTHERCOLUMN_FOM($K)</fom>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) HL_COLUMNS] }
1			<hla>$OTHERCOLUMN_HLA($K)</hla>
1			<hlb>$OTHERCOLUMN_HLB($K)</hlb>
1			<hlc>$OTHERCOLUMN_HLC($K)</hlc>
1			<hld>$OTHERCOLUMN_HLD($K)</hld>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) EVALUE_COLUMNS] }
1			<e>$OTHERCOLUMN_E($K)</e>
1			<sige>$OTHERCOLUMN_SIGE($K)</sige>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) FA_COLUMNS] }
1			<fa>$OTHERCOLUMN_FA($K)</fa>
1			<sigfa>$OTHERCOLUMN_SIGFA($K)</sigfa>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) ALPHA_COLUMNS] }
1			<alpha>$OTHERCOLUMN_ALPHA($K)</alpha>
ENDIF
1       </othercolumn>
ENDLOOP
1 			</mtz_in>
1

#######################
#      MTZ output     #
#######################

1 		<mtz_out>
1 			<filename>$TMP_HKLOUT</filename>

#
# Output Experimental Columns
#
1			<exp_columns>
LOOP K 1 $N_CRYSTALS
1		<crystal id="$K">
IF $CRYSTAL_NATIVE($K)
1			<data id="1">
1				<type>NATIVE</type>
1				<f>INPUT_X${K}_D1_F</f>
1				<sigf>INPUT_X${K}_D1_SIGF</sigf>
1				<i>INPUT_X${K}_D1_I</i>
1				<sigi>INPUT_X${K}_D1_SIGI</sigi>
1				<anomalous>0</anomalous>
1			</data>
ELSE
LOOP M 1 $N_DATA($K)
1			<data id="$M">
1				<type>$DATA_TYPE($K,$M)</type>
1				<f>INPUT_X${K}_D${M}_F</f>
1				<sigf>INPUT_X${K}_D${M}_SIGF</sigf>
1				<i>INPUT_X${K}_D${M}_I</i>
1				<sigi>INPUT_X${K}_D${M}_SIGI</sigi>
IF $DATA_ANOMALOUS($K,$M)
1				<f_plus>INPUT_X${K}_D${M}_F_PLUS</f_plus>
1				<sigf_plus>INPUT_X${K}_D${M}_SIGF_PLUS</sigf_plus>
1				<f_minus>INPUT_X${K}_D${M}_F_MINUS</f_minus>
1				<sigf_minus>INPUT_X${K}_D${M}_SIGF_MINUS</sigf_minus>
1				<dano>INPUT_X${K}_D${M}_DANO</dano>
1				<sigdano>INPUT_X${K}_D${M}_SIGDANO</sigdano>
1 				<isym>INPUT_X${K}_D${M}_ISYM</isym>
1				<i_plus>INPUT_X${K}_D${M}_I_PLUS</i_plus>
1				<sigi_plus>INPUT_X${K}_D${M}_SIGI_PLUS</sigi_plus>
1				<i_minus>INPUT_X${K}_D${M}_I_MINUS</i_minus>
1				<sigi_minus>INPUT_X${K}_D${M}_SIGI_MINUS</sigi_minus>
ENDIF
1				<anomalous>$DATA_ANOMALOUS($K,$M)</anomalous>
1			</data>
ENDLOOP
ENDIF
1		</crystal>
ENDLOOP
1			  </exp_columns>

#
# Output Other Data columns (F, Phase, HL, etc) with new names
#
LOOP K 1 $N_OTHERCOLUMN
1		<othercolumn id="$K">
1          <type>$OTHERCOLUMN_TYPE($K)</type>
IF { [StringSame $OTHERCOLUMN_TYPE($K) F_COLUMNS] }
1			<f>$OTHERCOLUMN_NEWLABEL_F($K)</f>
1			<sigf>$OTHERCOLUMN_NEWLABEL_SIGF($K)</sigf>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) PHASE_COLUMNS] }
1			<fb>$OTHERCOLUMN_NEWLABEL_FB($K)</fb>
1			<phib>$OTHERCOLUMN_NEWLABEL_PHIB($K)</phib>
1			<fom>$OTHERCOLUMN_NEWLABEL_FOM($K)</fom>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) HL_COLUMNS] }
1			<hla>$OTHERCOLUMN_NEWLABEL_HLA($K)</hla>
1			<hlb>$OTHERCOLUMN_NEWLABEL_HLB($K)</hlb>
1			<hlc>$OTHERCOLUMN_NEWLABEL_HLC($K)</hlc>
1			<hld>$OTHERCOLUMN_NEWLABEL_HLD($K)</hld>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) EVALUE_COLUMNS] }
1			<e>$OTHERCOLUMN_NEWLABEL_E($K)</e>
1			<sige>$OTHERCOLUMN_NEWLABEL_SIGE($K)</sige>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) FA_COLUMNS] }
1			<fa>$OTHERCOLUMN_NEWLABEL_FA($K)</fa>
1			<sigfa>$OTHERCOLUMN_NEWLABEL_SIGFA($K)</sigfa>
ENDIF
IF { [StringSame $OTHERCOLUMN_TYPE($K) ALPHA_COLUMNS] }
1			<alpha>$OTHERCOLUMN_NEWLABEL_ALPHA($K)</alpha>
ENDIF
1		</othercolumn>
ENDLOOP
1 	  </mtz_out>
1
1   </run>
1 </soap>
1 </crank>

